import { Component, TemplateRef, ViewChild } from '@angular/core';
import { BlockUnblockTransactionService } from '../block-unblock-transaction.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { AuthService } from '../services/auth.service';
import { ViewTransactionStatusForAgentService } from '../view-transaction-status-for-agent.service';

@Component({
  selector: 'app-block-unblock-transaction',
  templateUrl: './block-unblock-transaction.component.html',
  styleUrls: ['./block-unblock-transaction.component.css'],
})
export class BlockUnblockTransactionComponent {
  @ViewChild('viewTransactionReceipt') viewTransactionReceiptModal;
  bsTransactionReceiptModalRef: BsModalRef;

  bsModalRef: BsModalRef;

  @ViewChild('viewLog') viewLogModal;
  LogData: any;
  CountryDropdown: any;
  AgentDropdown: any;
  StatusDropDown: any;
  AgentBranchDropDown: any;
  DataList: any = [];
  AgentID: any = 0;
  AgentBranchID: any = 0;
  StatusId: any = -1;
  fromDate: any;
  toDate: any;
  transactionNo: any;
  isLoading: boolean = false;
  receiptData: any = {};

  constructor(
    private modalService: BsModalService,
    private BlockUnblockTransactionSvc: BlockUnblockTransactionService,
    private ViewTransactionStatusForAgentSvc: ViewTransactionStatusForAgentService,
    private authSvc: AuthService
  ) {}

  ngOnInit(): void {
    this.getCountry();
    this.fromDate = this.authSvc.getTodayDate();
    this.toDate = this.authSvc.getTodayDate();
  }
  getCountry() {
    this.isLoading = true;

    this.BlockUnblockTransactionSvc.getCountry().subscribe((res) => {
      this.CountryDropdown = res;
      this.isLoading = false;
    });
  }

  onSelectCountry(CountryID) {
    this.getAgent(CountryID);
    this.getStatus();
  }

  getAgent(CountryID) {
    this.BlockUnblockTransactionSvc.getAgent(CountryID).subscribe(
      (res: any) => {
        this.AgentDropdown = res;
        if (res?.length > 0) {
          this.getAgentbranch(res?.[0]?.Agent_ID);
        }
      }
    );
  }

  OnSelectAgent(AgentID) {
    this.AgentID = AgentID;
    this.getAgentbranch(AgentID);
  }

  getAgentbranch(AgentID) {
    this.BlockUnblockTransactionSvc.getAgentBranch(AgentID).subscribe((res) => {
      this.AgentBranchDropDown = res;
    });
  }

  onSelectAgentbranch(AgentBranchID) {
    this.AgentBranchID = AgentBranchID;
  }

  getStatus() {
    this.BlockUnblockTransactionSvc.getStatus().subscribe((res) => {
      this.StatusDropDown = res;
    });
  }

  onSelectStatus(StatusId) {
    this.StatusId = StatusId;
  }

  getBranchName(agent_id) {
    for (var i = 0; i < this.AgentBranchDropDown?.length; i++) {
      if (this.AgentBranchDropDown[i].AgentBranch_ID == agent_id) {
        return this.AgentBranchDropDown[i].AgentBranch_Name;
      }
    }
    return 'All';
  }
  getData() {
    if (!this.fromDate || !this.toDate) {
      alert('Please Select From & To Dates.');
      return;
    }
    const AgentBranch = this.getBranchName(this.AgentBranchID);

    this.BlockUnblockTransactionSvc.getDataByDate(
      this.fromDate,
      this.toDate,
      this.AgentID,
      this.StatusId,
      AgentBranch,
      this.AgentBranchID
    ).subscribe((res: any) => {
      if (res?.length == 0) {
        alert('No data found.');
        return;
      }
      this.DataList = res;
    });
  }

  openModal(template: TemplateRef<any>) {
    const modalOptions = {
      class: 'modal-lg', // Use large modal settings
      animated: true,
      keyboard: true,
      backdrop: true,
      ignoreBackdropClick: true,
    };
    this.bsModalRef = this.modalService.show(template, modalOptions);
  }

  getDatabyTransactionNo() {
    if (!this.transactionNo) {
      alert('Please Enter Transaction No.');
      return;
    }
    const payload = {
      G_UserGroup: '1',
      SubUserGroup_Id: '0',
      IsHeadOffice: 'true',
      TransactionNumber: String(this.transactionNo),
      AgentID: 0,
      AgentBranchID: 0,
      AgentBranchText: 'None',
    };
    this.BlockUnblockTransactionSvc.getDatabyTransactionNo(payload).subscribe(
      (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.DataList = res;
      }
    );
  }

  block(TransactionNumber) {
    this.BlockUnblockTransactionSvc.block(TransactionNumber).subscribe(
      (res) => {
        if (this.transactionNo) {
          this.getDatabyTransactionNo();
        } else {
          this.getData();
        }
        alert(res);
      }
    );
  }

  unBlock(TransactionNumber) {
    this.BlockUnblockTransactionSvc.unblock(TransactionNumber).subscribe(
      (res) => {
        if (this.transactionNo) {
          this.getDatabyTransactionNo();
        } else {
          this.getData();
        }
        alert(res);
      }
    );
  }

  getLog(TransactionNumber: any) {
    this.BlockUnblockTransactionSvc.getLog(TransactionNumber).subscribe(
      (res) => {
        this.LogData = res;
        this.openModal(this.viewLogModal);
      }
    );
  }
  view(TransactionNumber: any) {
    this.BlockUnblockTransactionSvc.View(TransactionNumber).subscribe((res) => {
      this.LogData = res;
      this.openModal(this.viewLogModal);
    });
  }
  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  getTransactionNumberDetail(item) {
    const trnNo = item?.SRTRNo;
    this.ViewTransactionStatusForAgentSvc.getTransactionReport(trnNo).subscribe(
      (res: any) => {
        if (res?.[0]?.IsDuplicate == true) {
          alert('No data found.');
          return;
        }
        this.receiptData = res?.[0];
        this.openTransactionReceiptModal(this.viewTransactionReceiptModal);
      }
    );
  }

  openTransactionReceiptModal(template: TemplateRef<any>) {
    this.bsTransactionReceiptModalRef = this.modalService.show(template, {
      class: 'modal-lg',
    });
  }
}
