import { Component, TemplateRef, ViewChild } from '@angular/core';
import { ChannelCancelTransactionService } from '../channel-cancel-transaction.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { getCacheData } from '../utils/helper';
import { AuthService } from '../services/auth.service';

@Component({
  selector: 'app-channel-cancel-transaction',
  templateUrl: './channel-cancel-transaction.component.html',
  styleUrls: ['./channel-cancel-transaction.component.css'],
})
export class ChannelCancelTransactionComponent {
  toDate: any;
  allData: any = [];
  frmDate: any;
  transactionNumber: any;
  trnNo: any;
  remark: any;
  bsModalRef: BsModalRef;
  @ViewChild('cancellationStatus') cancellationStatusModal;
  isLoading: boolean = false;

  constructor(
    private modalService: BsModalService,
    private ChannelCancelTransactionSvc: ChannelCancelTransactionService,
    private authSvc: AuthService
  ) {}

  ngOnInit() {
    this.frmDate = this.authSvc.getTodayDate();
    this.toDate = this.authSvc.getTodayDate();
  }

  searchByDate() {
    if (!this.frmDate || !this.toDate) {
      alert('Please Select From and To Dates.');
      return;
    }
    this.isLoading = true;

    this.ChannelCancelTransactionSvc.getDataByDate(
      this.frmDate,
      this.toDate
    ).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.allData = res;
        this.isLoading = false;
      },
      error: (err: any) => {
        this.isLoading = false;
        alert(err?.error?.message);
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }

  openModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template);
  }

  openCancellationStatusModal(item) {
    this.trnNo = item?.TransactionNumber;
    this.remark = item?.Remarks;
    this.openModal(this.cancellationStatusModal);
  }

  cancellationStatusSend() {
    const payload = {
      G_UserID: getCacheData('G_UserID'),
      TransactionNumber: this.trnNo,
      CustomerType: '1',
      Remark: this.remark,
      OrgMsgID: '0',
    };
    this.ChannelCancelTransactionSvc.cancellationStatus(payload).subscribe({
      next: (res: any) => {
        this.modalService.hide();
        alert(res);
      },
      error: (err: any) => {
        this.modalService.hide();
        alert(err?.error?.message);
      },
      complete: () => {
        this.modalService.hide();
      },
    });
  }

  resend() {
    const payload = {
      G_UserID: '0',
      TransactionNumber: this.trnNo,
      CustomerType: '1',
      Remark: this.remark,
    };
    this.ChannelCancelTransactionSvc.resend(payload).subscribe({
      next: (res: any) => {
        this.modalService.hide();
        alert(res);
      },
      error: (err: any) => {
        this.modalService.hide();
        alert(err?.error?.message);
      },
      complete: () => {
        this.modalService.hide();
      },
    });
  }

  searchByTransactionNumber() {
    if (!this.transactionNumber) {
      alert('Please Enter Transaction No.');
      return;
    }
    this.isLoading = true;

    this.ChannelCancelTransactionSvc.getDataByTransactionNumber(
      this.transactionNumber
    ).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.allData = res;
        this.isLoading = false;
      },
      error: (err: any) => {
        this.isLoading = false;
        alert(err?.error?.message);
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }
  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
