import { Component, ElementRef, TemplateRef, ViewChild } from '@angular/core';
import { ChannelHoldTransactionService } from '../channel-hold-transaction.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { getCacheData } from '../utils/helper';
import { AuthService } from '../services/auth.service';
import { ViewTransactionStatusForAgentService } from '../view-transaction-status-for-agent.service';
import * as XLSX from 'xlsx';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-channel-hold-transaction',
  templateUrl: './channel-hold-transaction.component.html',
  styleUrls: ['./channel-hold-transaction.component.css'],
})
export class ChannelHoldTransactionComponent {
  @ViewChild('processFailTransaction') processFailTransactionModal;
  bsModalRef: BsModalRef;

  @ViewChild('viewTransactionReceipt') viewTransactionReceiptModal;
  bsTransactionReceiptModalRef: BsModalRef;
  @ViewChild('transactionTable') transactionTable: ElementRef;

  toDate: any;
  fromDate: any;
  allDataByDate: any = [];
  TransactionNumber: any;
  isLoading: boolean = false;
  trnNo: any = '';
  customerType: any = '';
  mid: any = '';
  remarks: any = '';
  receiptData: any = {};

  constructor(
    private ChannelHoldTransactionSvc: ChannelHoldTransactionService,
    private modalService: BsModalService,
    private authSvc: AuthService,
    private ViewTransactionStatusForAgentSvc: ViewTransactionStatusForAgentService,
    private toastrSvc: ToastrService
  ) {}

  ngOnInit(): void {
    this.fromDate = this.authSvc.getTodayDate();
    this.toDate = this.authSvc.getTodayDate();
  }

  getDataByDate() {
    if (!this.fromDate || !this.toDate) {
      alert('Please Select From and To Dates.');
      return;
    }

    this.isLoading = true;

    this.ChannelHoldTransactionSvc.getAllRecord(
      this.fromDate,
      this.toDate
    ).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.allDataByDate = res;
      },
      error: () => {
        this.isLoading = false;
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }

  getDataByTransactionNo() {
    this.isLoading = true;

    this.ChannelHoldTransactionSvc.getRecordByTransactionNo(
      this.TransactionNumber
    ).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.allDataByDate = res;
      },
      error: () => {
        this.isLoading = false;
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }

  openProcessFailTransactionModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template, {
      class: 'modal-lg',
    });
  }

  onStatusClick(transaction) {
    console.log('transaction: ', transaction);
    if (transaction) {
      const hlink = transaction?.hlink;
      // Create a URL object with a base URL
      const url = new URL(hlink, window.location.origin);

      // Extract parameters using URLSearchParams
      const params = new URLSearchParams(url.search);
      this.trnNo = params.get('TxnNo');
      this.customerType = params.get('CT');
      this.mid = params.get('mid');
      this.openProcessFailTransactionModal(this.processFailTransactionModal);
    }
  }

  approvedTransaction() {
    if (!this.remarks) {
      alert('Please Enter Remarks.');
      return;
    }
    const payload = {
      TransactionNumber: this.trnNo,
      Remark: this.remarks,
      G_UserID: getCacheData('G_UserID'),
      CustomerType: this.customerType,
      OrgMsgID: this.mid,
    };
    this.ChannelHoldTransactionSvc.approvedTransaction(payload).subscribe({
      next: (res: any) => {},
      error: (err) => {
        // alert(err?.error?.message);
        this.toastrSvc.error(err?.error?.message);
      },
      complete: () => {},
    });
  }

  rejectTransaction() {
    if (!this.remarks) {
      alert('Please Enter Remarks.');
      return;
    }
    const payload = {
      TransactionNumber: this.trnNo,
      Remark: this.remarks,
      G_UserID: getCacheData('G_UserID'),
      CustomerType: this.customerType,
      OrgMsgID: this.mid,
    };
    this.ChannelHoldTransactionSvc.rejectTransaction(payload).subscribe({
      next: (res: any) => {},
      error: (err) => {
        // alert(err?.error?.message);
        this.toastrSvc.error(err?.error?.message);
      },
      complete: () => {},
    });
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  getTransactionNumberDetail(item) {
    const trnNo = item?.TransactionNumber;
    this.ViewTransactionStatusForAgentSvc.getTransactionReport(trnNo).subscribe(
      (res: any) => {
        if (res?.[0]?.IsDuplicate == true) {
          alert('No data found.');
          return;
        }
        this.receiptData = res?.[0];
        this.openTransactionReceiptModal(this.viewTransactionReceiptModal);
      }
    );
  }

  openTransactionReceiptModal(template: TemplateRef<any>) {
    this.bsTransactionReceiptModalRef = this.modalService.show(template, {
      class: 'modal-lg',
    });
  }

  exportToExcel() {
    const ws: XLSX.WorkSheet = XLSX.utils.table_to_sheet(
      this.transactionTable.nativeElement
    );
    const wb: XLSX.WorkBook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(wb, ws, 'Sheet1');
    const fileName = `Channel_Hold_Transaction${Date.now()}.xlsx`;
    XLSX.writeFile(wb, fileName);
  }
}
