import { Component, ElementRef, ViewChild } from '@angular/core';
import * as XLSX from 'xlsx';
import { ComplianceReleasedTransactionReportService } from '../services/compliance-released-transaction-report.service';

@Component({
  selector: 'app-compliance-released-transaction-report',
  templateUrl: './compliance-released-transaction-report.component.html',
  styleUrls: ['./compliance-released-transaction-report.component.css'],
})
export class ComplianceReleasedTransactionReportComponent {
  @ViewChild('complianceTransactionTable')
  complianceTransactionTable: ElementRef;
  isLoading: boolean = false;
  transactionNo: any = '';
  fromDate: string = new Date(new Date().toLocaleString("en-US", {timeZone: "Asia/Riyadh"})).toISOString().substring(0, 10);
  toDate: string = new Date(new Date().toLocaleString("en-US", {timeZone: "Asia/Riyadh"})).toISOString().substring(0, 10);
  
  allComplianceTransactions: any = [];
  selectedFileFormat: any = '1';

  constructor(
    private complianceTransactionSvc: ComplianceReleasedTransactionReportService
  ) {}

  ngOnInit(): void {}

  filterByTransactioNo() {
    if (!this.transactionNo) {
      alert('Please Enter Transaction No!');
      return;
    }
    this.isLoading = true; 
    this.complianceTransactionSvc
      .getDataByTransactionNo(this.transactionNo)
      .subscribe({
        next: (res: any) => {
          this.isLoading = false; 
          if (res?.length == 0) {
            this.allComplianceTransactions = [];
            alert('No data found.');
            return;
          }
          this.allComplianceTransactions = res;
          this.transformData();
        },
        error: (err) => {
          this.isLoading = false; 
          this.allComplianceTransactions = [];
          alert(err?.error?.message || 'Something went wrong');
        },
        complete: () => {},
      });
  }

  displayByDate() {
    if (!this.fromDate || !this.toDate) {
      alert('Please Select From & To Date!');
      return;
    }

    this.complianceTransactionSvc
      .getFillGrid(this.fromDate, this.toDate)
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            this.allComplianceTransactions = [];
            alert('No data found.');
            return;
          }
          this.allComplianceTransactions = res;
          this.transformData();
        },
        error: (err) => {
          this.allComplianceTransactions = [];
          alert(err?.error?.message || 'Something went wrong');
        },
        complete: () => {},
      });
  }

  exportToExcel() {
    /* generate worksheet */
    const ws: XLSX.WorkSheet = XLSX.utils.table_to_sheet(
      this.complianceTransactionTable.nativeElement
    );

    /* generate workbook and add the worksheet */
    const wb: XLSX.WorkBook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(wb, ws, 'Sheet1');

    /* save to file */
    const fileName = `Compliance_Released_Transactions${Date.now()}.xlsx`;
    XLSX.writeFile(wb, fileName);
  }

  transformData() {
    this.allComplianceTransactions = this.allComplianceTransactions.map(
      (item) => {
        const newItem = {};
        for (const key in item) {
          if (item.hasOwnProperty(key)) {
            const newKey = key.replace(/^\*|(?<=,)\*|\*(?=,|$)|\s+/g, ''); // Remove asterisk and replace spaces with underscores
            newItem[newKey] = item[key];
          }
        }
        return newItem;
      }
    );
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
