import { Component, TemplateRef, ViewChild } from '@angular/core';
import { CtaHoldMarginService } from '../services/cta-hold-margin.service';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { getCacheData } from '../utils/helper';
@Component({
  selector: 'app-cta-hold-margin',
  templateUrl: './cta-hold-margin.component.html',
  styleUrls: ['./cta-hold-margin.component.css'],
})
export class CtaHoldMarginComponent {
  @ViewChild('ctaHoldMargin') ctaHoldMarginModal;
  bsModalRef: BsModalRef;
  isLoading: boolean = false; // Loader flag

  allSendCountryList: any = [];
  sendCountryList: any = [];
  selectedSendCountry: any;
  receiveCountryList: any = [];
  sendCurrencyList: any = [];
  receiveCurrencyList: any = [];

  ctaHoldMargins: any = [];
  type: any = 'add';

  ctaHoldMarginForm = new FormGroup({
    Id: new FormControl(),
    SendCountryId: new FormControl('None', Validators.required),
    SendCurrencyId: new FormControl('None', Validators.required),
    ReceiveCountryId: new FormControl('None', Validators.required),
    ReceiveCurrencyId: new FormControl('None', Validators.required),
    Margin: new FormControl('', Validators.required),
  });

  constructor(
    private ctaHoldMarginService: CtaHoldMarginService,
    private modalService: BsModalService
  ) {}

  ngOnInit(): void {
    this.getSendCountryList();
    this.getReceiveCountryList();
  }

  getSendCountryList() {
    this.ctaHoldMarginService.getSendCountryList().subscribe({
      next: (res: any) => {
        this.sendCountryList = res;
        this.selectedSendCountry = res?.[0]?.CountryId;
        if (!this.allSendCountryList.length) {
          this.allSendCountryList = [...res];
        }
      },
      error: (err) => {
        this.sendCountryList = [];
      },
      complete: () => {},
    });
  }

  onSendCountryChange(countryId: any, sendCurrency = '') {
    if (countryId) {
      this.getSendCurrencyList(countryId, sendCurrency);
    }
  }

  getSendCurrencyList(sendCountryId: any = 0, sendCurrency = '') {
    this.ctaHoldMarginService.getSendCurrencyList(sendCountryId).subscribe({
      next: (res: any) => {
        this.sendCurrencyList = res;
        if (this.type == 'add') {
          this.ctaHoldMarginForm.patchValue({
            SendCurrencyId: this.sendCurrencyList?.[0]?.Currency_Id,
          });
        }
        if (this.type == 'edit') {
          const sendCurrencyId = this.sendCurrencyList.find(
            (c) => c.CurrencyName == sendCurrency
          ).Currency_Id;
          this.ctaHoldMarginForm.patchValue({
            SendCurrencyId: sendCurrencyId,
          });
        }
      },
      error: (err) => {
        this.sendCurrencyList = [];
      },
      complete: () => {},
    });
  }

  getReceiveCountryList() {
    this.ctaHoldMarginService.getReceiveCountryList().subscribe({
      next: (res: any) => {
        this.receiveCountryList = res;
      },
      error: (err) => {
        this.receiveCountryList = [];
      },
      complete: () => {},
    });
  }

  onReceiveCountryChange(countryId: any, receiveCurrency = '') {
    if (countryId) {
      this.getReceiveCurrencyList(countryId, receiveCurrency);
    }
  }

  getReceiveCurrencyList(receiveCountryId: any = 0, receiveCurrency = '') {
    this.ctaHoldMarginService
      .getReceiveCurrencyList(receiveCountryId)
      .subscribe({
        next: (res: any) => {
          this.receiveCurrencyList = res;
          if (this.type == 'add') {
            this.ctaHoldMarginForm.patchValue({
              ReceiveCurrencyId: this.receiveCurrencyList?.[0]?.Currency_Id,
            });
          }
          if (this.type == 'edit') {
            const receiveCurrencyId = this.receiveCurrencyList.find(
              (c) => c.CurrencyName == receiveCurrency
            ).Currency_Id;
            this.ctaHoldMarginForm.patchValue({
              ReceiveCurrencyId: receiveCurrencyId,
            });
            this.openCtaHoldMarginModal('edit');
          }
        },
        error: (err) => {
          this.receiveCurrencyList = [];
        },
        complete: () => {},
      });
  }

  displayData() {
    this.isLoading = true;
    if (this.selectedSendCountry) {
      this.ctaHoldMarginService
        .getFillGrid(this.selectedSendCountry)
        .subscribe({
          next: (res: any) => {
            if (res?.length == 0) {
              alert('No data found.');
              this.isLoading = false;
              return;
            }
            this.ctaHoldMargins = res;
            this.isLoading = false;
          },
          error: (err) => {
            this.ctaHoldMargins = [];
            this.isLoading = false;
          },
          complete: () => {
            this.isLoading = false;
          },
        });
    }
  }
  openModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template);
  }

  openCtaHoldMarginModal(type: any) {
    if (type == 'add') {
      this.ctaHoldMarginForm.reset({
        SendCountryId: this.sendCountryList.find((c) => c.CountryId)?.CountryId,
        ReceiveCountryId: this.receiveCountryList.find((c) => c.CountryId)
          ?.CountryId,
      });
      this.onSendCountryChange(this.f.SendCountryId);
      this.onReceiveCountryChange(this.f.ReceiveCountryId);
    }
    this.type = type;
    this.openModal(this.ctaHoldMarginModal);
  }

  get f() {
    return this.ctaHoldMarginForm.value;
  }



  addCTAHoldMargin() {
    if (!this.ctaHoldMarginForm.valid) {
      alert('Please Fill Required Fields!');
      return;
    }

    if (this.f.SendCountryId == 'None') {
      alert('Please Select Sending Country!');
      return;
    }

    if (this.f.SendCurrencyId == 'None') {
      alert('Please Select Sending Currency!');
      return;
    }

    if (this.f.ReceiveCountryId == 'None') {
      alert('Please Select Receiving Country!');
      return;
    }

    if (this.f.ReceiveCurrencyId == 'None') {
      alert('Please Select Receiving Currency!');
      return;
    }

    let payload;
    payload = {
      SendCountryId: this.f.SendCountryId,
      SendCurrencyId: this.f.SendCurrencyId,
      ReceiveCountryId: this.f.ReceiveCountryId,
      ReceiveCurrencyId: this.f.ReceiveCurrencyId,
      Margin: this.f.Margin,
    };

    if (this.type === 'edit') {
      payload = {
        ...payload,
        Id: this.f.Id,
      };
    }

    const serviceMethod =
      this.type === 'add' ? 'addCTAHoldMargin' : 'updateCTAHoldMargin';

    this.ctaHoldMarginService[serviceMethod](payload).subscribe({
      next: (res: any) => {
        this.modalService.hide();
        const message = this.type === 'edit' ? 'updated' : 'added';
        alert(`CTA Hold Margin information ${message} successfully.`);
      },
      error: (err) => {
        this.modalService.hide();
        alert(err?.error?.message || 'Something went wrong');
      },
      complete: () => {
        this.modalService.hide();
      },
    });
  }

  editCTAHoldMargin(ctaHoldMargin: any) {
    this.type = 'edit';
    const sendCountryId = this.sendCountryList.find(
      (c) => c.CountryName == ctaHoldMargin.SendCountryName
    )?.CountryId;
    const receiveCountryId = this.receiveCountryList.find(
      (c) => c.CountryName == ctaHoldMargin.ReceCountryName
    )?.CountryId;
    this.ctaHoldMarginForm.patchValue({
      Id: ctaHoldMargin.Id,
      SendCountryId: sendCountryId,
      ReceiveCountryId: receiveCountryId,
      Margin: ctaHoldMargin.Margin,
    });
    this.onSendCountryChange(sendCountryId, ctaHoldMargin?.SendCurrencyName);
    this.onReceiveCountryChange(
      receiveCountryId,
      ctaHoldMargin?.ReceCurrencyName
    );
  }

  isCTAHoldMargin(margin: any) {
    if (!margin) {
      return false;
    }
    return true;
  }

  updateCTAHoldMargin(): void {
    const updatedCTAHold = this.ctaHoldMargins
      .filter((con) => con.isChecked)
      .map((con) => {
        return {
          IsCheckEdit: con?.isChecked,
          IsActive: con?.IsActive,
          Id: con?.Id,
          Margin: con?.Margin,
          UserID:getCacheData('G_UserID'),
        };
      });
    if (updatedCTAHold?.length) {
      this.ctaHoldMarginService.updateCTAHoldMargin(updatedCTAHold).subscribe({
        next: (res: any) => {
          this.modalService.hide();
          alert('Record Updated Successfully.');
          this.displayData();
        },
        error: (err) => {
          this.modalService.hide();
          alert(err?.error?.message || 'Something went wrong');
        },
        complete: () => {
          this.modalService.hide();
        },
      });
    }
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
  allowOneDecimal(event: any) {
    let input = event.target.value;
    // Allow only one decimal point and restrict to up to four digits after the decimal point
    if (input.indexOf('.') != -1) {
      let parts = input.split('.');
      if (parts.length > 2) {
        parts = [parts[0], parts.slice(1).join('')]; // Join any extra decimals
      }
      parts[1] = parts[1].replace(/[^0-9]/g, ''); // Remove non-digit characters
      event.target.value = parts[0] + '.' + parts[1].slice(0, 4); // Limit to 4 decimal places
    }
  }

  formatToFourDecimalsOnBlur(index: number, event: any) {
    let input = parseFloat(event.target.value);
    if (!isNaN(input)) {
      this.ctaHoldMargins[index].Margin = parseFloat(input.toFixed(4)); // Update the model
      event.target.value = input.toFixed(4); // Update the display value
    }
  }

  // Update the model to reflect the formatted value
 
  
}
