import { Component, ViewChild } from '@angular/core';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { BsModalRef } from 'ngx-bootstrap/modal';
import { getCacheData } from '../utils/helper';
import { DailyRatesService } from '../services/daily-rates.service';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-daily-rates',
  templateUrl: './daily-rates.component.html',
  styleUrls: ['./daily-rates.component.css'],
})
export class DailyRatesComponent {
  @ViewChild('manageBankRates') manageBankRatesModal;
  bsModalRef: BsModalRef;

  type: any = 'add';
  isLoading: boolean = false; // Loader flag

  sendingCountries: any = [];
  selectedSendCountry: any = 'Select Country';

  receivingCountries: any = [];
  selectedReceivingCountry: any = 'All';

  sendingAgents: any = [];
  selectedSendingAgent: any = 'All';

  receivingAgents: any = [];
  selectedReceivingAgent: any = 'All';

  cifNumbers: any = [];
  selectedCifNumber: any = 'All';

  dailyRates: any = [];

  manageBankRatesForm = new FormGroup({
    AutoRateflag: new FormControl(false),
    Settelment_Rate: new FormControl('', Validators.required),
    Revalution_Rate: new FormControl('', Validators.required),
    Offer_Rate: new FormControl('', Validators.required),
    Bid_Rate: new FormControl('', Validators.required),
    ModeOfPayment_ID: new FormControl('', Validators.required),
    Agent_ID: new FormControl('', Validators.required),
    ToCurrency_Id: new FormControl('', Validators.required),
    ToCountry_ID: new FormControl('None', Validators.required),
    SettlementCurrency: new FormControl('', Validators.required),
    ID: new FormControl(),
  });

  constructor(private dailyRateService: DailyRatesService,    private toastrSvc: ToastrService
  ) {}

  ngOnInit(): void {
    this.getSendCountry();
    this.getCIFNumbers();
  }

  getSendCountry(userId: any = 0, countryType: any = 0) {
    this.dailyRateService
      .getSendCountry(
        getCacheData('admin_token'),
        getCacheData('username'),
        userId,
        countryType
      )
      .subscribe({
        next: (res: any) => {
          this.sendingCountries = res;
        },
        error: () => {
          this.sendingCountries = [];
        },
        complete: () => {},
      });
  }

  getReceivingCountry(countryId: any = 0) {
    this.dailyRateService
      .getReceiveCountry(
        getCacheData('admin_token'),
        getCacheData('username'),
        countryId
      )
      .subscribe({
        next: (res: any) => {
          this.receivingCountries = res;
        },
        error: () => {
          this.receivingCountries = [];
        },
        complete: () => {},
      });
  }

  getSendingAgent(countryId: any = 0) {
    this.dailyRateService
      .getSendingAgent(
        getCacheData('admin_token'),
        getCacheData('username'),
        countryId
      )
      .subscribe({
        next: (res: any) => {
          this.sendingAgents = res;
        },
        error: () => {
          this.sendingAgents = [];
        },
        complete: () => {},
      });
  }

  getReceivingAgent(countryId: any = 0) {
    this.dailyRateService
      .getReceivingAgent(
        getCacheData('admin_token'),
        getCacheData('username'),
        countryId
      )
      .subscribe({
        next: (res: any) => {
          this.receivingAgents = res;
        },
        error: () => {
          this.receivingAgents = [];
        },
        complete: () => {},
      });
  }

  getCIFNumbers() {
    this.dailyRateService
      .getCIFNumbers(getCacheData('admin_token'), getCacheData('username'))
      .subscribe({
        next: (res: any) => {
          this.cifNumbers = res;
        },
        error: () => {
          this.cifNumbers = [];
        },
        complete: () => {},
      });
  }

  get f() {
    return this.manageBankRatesForm.value;
  }

  onSendCountryChange() {
    this.dailyRates = [];
    if (this.selectedSendCountry != 'Send Country') {
      this.getSendingAgent(this.selectedSendCountry);
      this.getReceivingCountry(this.selectedSendCountry);
    }
  }

  onReceiveCountryChange() {
    this.dailyRates = [];
    if (this.selectedReceivingCountry != 'All') {
      // this.getSendingAgent(this.selectedSendCountry);
      this.getReceivingAgent(this.selectedReceivingCountry);
    }
  }

  onSendAgentChange() {
    this.dailyRates = [];

    console.log(this.selectedReceivingCountry)
    if (this.selectedReceivingCountry != 'All') {
       console.log(this.selectedReceivingCountry)
      // this.getReceivingAgent(this.selectedReceivingCountry);
      this.getCIFNumbers();
    }
  }

  searchDailyRates() {
    this.isLoading = true;
    let sendCountryId: number | null = 0;
    let receiveCountryId: number | null = 0;
    let sendAgentId: number | null = 0;
    let receiveAgentId: number | null = 0;
    let cifNumber: string | null = '';

    if (this.selectedSendCountry !== 'Select Country') {
      sendCountryId = this.selectedSendCountry;
    }

    if (this.selectedReceivingCountry !== 'All') {
      receiveCountryId = this.selectedReceivingCountry;
    }

    if (this.selectedSendingAgent !== 'All') {
      sendAgentId = this.selectedSendingAgent;
    }

    if (this.selectedReceivingAgent !== 'All') {
      receiveAgentId = this.selectedReceivingAgent;
    }

    if (this.selectedCifNumber !== 'All') {
      cifNumber = this.selectedCifNumber;
    }

    let payload;
    payload = {
      CountryID: sendCountryId,
      AgentID: sendAgentId,
      TargetCountryID: receiveCountryId,
      TargetAgentID: receiveAgentId,
      CIFNumber: cifNumber,
      SessionBaseCurrencyID: getCacheData('Base_Currency_ID'),
      SessionAgentCountryID:getCacheData('Agent_Country_ID'),
      SessionG_Agent_ID: getCacheData('G_Agent_ID'),
      SessionG_UserGroup:  getCacheData('G_UserGroup'),
      SessionSubUserGroup_Id:  getCacheData('SubUserGroup_Id'),
      IsSubAgent: getCacheData('IsSubAgent')
    };
   



    this.getAllDailyRates(payload);
  }

  getAllDailyRates(payload) {
    this.dailyRateService
      .getAllDailyRates(
        getCacheData('admin_token'),
        getCacheData('username'),
        payload
      )
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            alert('No data found.');
            this.isLoading = false;

            return;
          }
          this.dailyRates = res;
          this.isLoading = false;

        },
        error: () => {
          this.dailyRates = [];
          this.isLoading = false;

        },
        complete: () => {},
      });
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
