import { Component, OnInit } from '@angular/core';
import { DataMappingService } from '../services/data-mapping.service';
import { ToastrService } from 'ngx-toastr';

@Component({
  selector: 'app-data-mapping',
  templateUrl: './data-mapping.component.html',
  styleUrls: ['./data-mapping.component.css']
})
export class DataMappingComponent implements OnInit {
  records: any[] = [];
  isLoading: boolean = false;

  xmlTagList: string[] = [];
  trTagList: string[] = [];
  mappingTypes: any = [];
  selectedMappingType: any | null = null; // Property to store the selected value
  selectedChannelType: any | null = null; // Property to store the selected value
  selectedAgentId: any | null = null; // Property to store the selected value
  selectedPayOutItemId: any | null = null; // Property to store the selected value
  agents: any = [];
  sendAgent: any = [];
  datatable: any = [];
  Tritem: any = [];
  sendAgentpayOut: any = [];
  selectedTrItemId: number | null = null; // To store the selected TRItem ID
  selectedPayOutAgentId: number | null = null; // To store the selected TRItem ID
  isActive: any | null = null; // To store the selected IsActive status

  constructor( private dataMappingService: DataMappingService, private toastrSvc: ToastrService) {
    // Initialize the data for demonstration purposes
    // this.records = [
    //   { id: 1, XmlTagName: 'tag1', TRTagName: 'tr1', editing: false },
    //   { id: 2, XmlTagName: 'tag2', TRTagName: 'tr2', editing: false }
    // ];

    // Initialize the tag lists with sample data
    this.xmlTagList = ['tag1', 'tag2', 'tag3'];
    this.trTagList = ['tr1', 'tr2', 'tr3'];
  }

  ngOnInit(): void {
    this.dataMappingService.getMappingType(1, 0, 0, 0, 0, 0).subscribe({
      next: (response) => {
        console.log('Response from getfillgrid:', response);
        this.mappingTypes = response;

      },
      error: (error) => {
        console.error('Error fetching grid data:', error);
      }
    });
  }

  editRecord(record: any): void {
    record.editing = true;
  }

  mapRecord(record: any): void {
    // Placeholder for the actual mapping logic

console.log(record,record.ID)

    this.dataMappingService.updateData(
      this.selectedMappingType, 
      this.selectedPayOutAgentId,
      this.selectedAgentId,
      record.ID,
      this.selectedTrItemId, 
      this.selectedPayOutItemId,
      this.isActive
    ).subscribe(
      response => {
        // Handle successful response here if needed
        console.log('Insert response:', response);
        window.alert('PaymentMode Mapped Record Inserted Successfully');
        this.fetchMappingTypes(); // Example method call to refresh the list
        record.editing = false;
      },
      error => {
        // Handle error response
        if (error.error && error.error.message === 'PaymentMode Already Mapped') {
          window.alert('PaymentMode Already Mapped');
          record.editing = false;
        } else {
          console.error('Insert error:', error);
          window.alert('Something went wrong while processing this request.');
          record.editing = false;
        }
      }
    );
  }

  cancelEdit(record: any): void {
    record.editing = false;
  }

  toggleSideBar(): void {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  onMappingTypeChange(event: any): void {
    const selectedValue = event.target.value;
    console.log(`Selected Mapping Type Value: ${selectedValue}`);

    // Call the endpoint with the selected value
    this.dataMappingService.getMappingAgentListSnd(selectedValue, 0, 0, 0, 0, 0).subscribe({
      next: (response: any) => {
        console.log('Response for selected mapping type:', response);
        this.agents = response; // Save response to the 'agents' variable
      },
      error: (error) => {
        console.error('Error fetching data for selected mapping type:', error);
      }
    });
  }


  onChannelChange(event: any): void {
     this.selectedAgentId = event.target.value;
    console.log(`Selected Agent ID: ${ this.selectedAgentId}`);
    this.dataMappingService.getMappingTritem(this.selectedMappingType,  this.selectedAgentId, 0, 0, 0, 0).subscribe({
      next: (response: any) => {
        console.log('Response for selected mapping type:', response);
        this.Tritem = response; // Save response to the 'agents' variable
      },
      error: (error) => {
        console.error('Error fetching data for selected mapping type:', error);
      }
    });
    this.fetchMappingTypes()
  }

  onTrItemChange(event: any): void {
    this.selectedTrItemId = event.target.value;
    console.log(`Selected TR Item ID: ${this.selectedTrItemId}`);
    this.dataMappingService.getMappingAgentList(this.selectedMappingType, this.selectedAgentId, 0, this.selectedTrItemId, 0, 0).subscribe({
      next: (response: any) => {
        console.log('Response for selected mapping type:', response);
        this.sendAgent = response; // Save response to the 'agents' variable
      },
      error: (error) => {
        console.error('Error fetching data for selected mapping type:', error);
      }
    });
    this.fetchMappingTypes()
  }

  onPayOutAgentChange(event: any): void {
    this.selectedPayOutAgentId = event.target.value;
    console.log(`Selected PayOut Agent ID: ${this.selectedPayOutAgentId}`);
    this.dataMappingService.getMappingpayout(this.selectedMappingType, this.selectedAgentId, this.selectedPayOutAgentId, this.selectedTrItemId, 0, 0).subscribe({
      next: (response: any) => {
        console.log('Response for selected mapping type:', response);
        this.sendAgentpayOut = response; // Save response to the 'agents' variable
      },
      error: (error) => {
        console.error('Error fetching data for selected mapping type:', error);
      }
    });
    this.fetchMappingTypes()
  }


  onPayOutItemChange(event: any): void {
    this.selectedPayOutItemId = event.target.value;
    console.log(`Selected PayOut Item ID: ${this.selectedPayOutItemId}`);
   this.fetchMappingTypes()
  }

  fetchMappingTypes(): void {

    this.isLoading=true
    this.dataMappingService.getfillgrid(this.selectedMappingType,  this.selectedPayOutAgentId,this.selectedAgentId,this.selectedTrItemId, this.selectedPayOutItemId,this.isActive).subscribe({
      next: (response) => {
        this.isLoading=false

        console.log('Response from getMappingType:', response);
        this.records = response as any[]; // Cast response to any[]
      },
      error: (error) => {
        this.isLoading=false

        console.error('Error fetching mapping types:', error);
        this.records = [] as any[];
      }
    });
  }

  applyFilters(): void {
    console.log('Applying filters...');
    this.fetchMappingTypes()
   
  }

  delete(rd: any): void {
    // Show a confirmation dialog to the user
    const confirmed = window.confirm('Do you want to remove this mapping?');
    
    if (confirmed) {
      // If the user confirms, proceed with the deletion
      this.dataMappingService.deleteMapping(this.selectedMappingType, rd.ID).subscribe(
        response => {
          // Show success message after successful deletion
          window.alert('PaymentMode Mapped Record Delete Successful');
          // Handle additional logic if needed, such as refreshing the list or updating the UI
          this.fetchMappingTypes(); // Example method call to refresh the list
        },
        error => {
          // Log or handle the error
          console.error('Delete error:', error);
        }
      );
    }
  }


  insert(): void {
    // Show a confirmation dialog to the user
    

    if (!this.selectedMappingType) {
      return  window.alert('Mapping Type is required')  
    }
    if (!this.selectedPayOutAgentId) {
      return   window.alert('PayOut Agent ID is required')  ;
    }
    if (!this.selectedAgentId) {
      return  window.alert( 'Send Agent ID is required') ;
    }
    if (!this.selectedTrItemId) {
      return  window.alert('TR Item ID is required') ;
    }
    if (!this.selectedPayOutItemId) {
      return window.alert('PayOut Item ID is required.') ;
    }
    if (this.isActive == null) {
    return  window.alert('IsActive status is required') ;
    }
  
    // If there are any errors, show the message and return early
  
  
     
      this.dataMappingService.insertData(
        this.selectedMappingType, 
        this.selectedPayOutAgentId,
        this.selectedAgentId,
        this.selectedTrItemId, 
        this.selectedPayOutItemId,
        this.isActive
      ).subscribe(
        response => {
          // Handle successful response here if needed
          console.log('Insert response:', response);
          window.alert('PaymentMode Mapped Record Inserted Successfully');
          this.fetchMappingTypes(); // Example method call to refresh the list
        },
        error => {
          // Handle error response
          if (error.error && error.error.message === 'PaymentMode Already Mapped') {
            window.alert('PaymentMode Already Mapped');
          } else {
            console.error('Insert error:', error);
            window.alert(error.error.message);
          }
        }
      );
    
  }
  
  getAgentNameById(agentId: any): string {
    // Find the agent in the agents array that matches the agentId
    const agent = this.agents.find(agent => agent.Agent_ID == agentId);
    // Return the corresponding name or a placeholder if not found
    return agent ? agent.Agent_Name : agentId;
  }

  getTRItemNameById(trItemId: any): string {
    // Find the item in the TRItems array that matches the trItemId
    const item = this.Tritem.find(trItem => trItem.TRItemID == trItemId);
    // Return the corresponding name or a placeholder if not found
    return item ? item.TRItemName : trItemId;
  }


  getPayoutItemNameById(payoutItemId: any): string {

    console.log(payoutItemId)
    
    // Find the item in the sendAgentpayOut array that matches the payoutItemId
    const item = this.sendAgentpayOut.find(payOutItem => payOutItem.PayOutItemID == payoutItemId);
    console.log(item)
    // Return the corresponding name or a placeholder if not found
    return item ? item.PayOutItemName : payoutItemId;
  } 


  displayIsActive(isActive: any): string {
    if (isActive == 1) {
      return 'True';
    } else if (isActive == 0) {
      return 'False';
    }else if(isActive == 9){
      return 'Select isActive';
    } else {
      return isActive; // or any placeholder for null/undefined values
    }
  }

// In your component.ts file
onIsActiveChange(newValue: number): void {
  // Update the record's IsActive property with the new value
this.isActive =newValue
  // Log the change or perform any other logic
  console.log(`IsActive changed to: ${newValue} `);

  // Optionally, update other variables or call methods based on this change
  // For example, you might want to auto-save or update other parts of the record
  // this.autoSave(record);
}

PayoutItemName(newValue: number): void {
  // Update the record's IsActive property with the new value
this.selectedPayOutItemId =newValue
  // Log the change or perform any other logic
  console.log(`IsActive changed to: ${newValue} `);

  // Optionally, update other variables or call methods based on this change
  // For example, you might want to auto-save or update other parts of the record
  // this.autoSave(record);
}
TRItemName(newValue: number): void {
  // Update the record's IsActive property with the new value
  this.selectedTrItemId =newValue
  // Log the change or perform any other logic
  console.log(`IsActive changed to: ${newValue} `);

  // Optionally, update other variables or call methods based on this change
  // For example, you might want to auto-save or update other parts of the record
  // this.autoSave(record);
}
SendAgentName(newValue: number): void {
  // Update the record's IsActive property with the new value
  this.selectedAgentId =newValue
  // Log the change or perform any other logic
  console.log(`IsActive changed to: ${newValue} `);

  // Optionally, update other variables or call methods based on this change
  // For example, you might want to auto-save or update other parts of the record
  // this.autoSave(record);
}



}
