import { Component, OnInit } from '@angular/core';
import { ErrorLogReportService } from '../services/error-log-report.service';

@Component({
  selector: 'app-error-log-report',
  templateUrl: './error-log-report.component.html',
  styleUrls: ['./error-log-report.component.css'],
})
export class ErrorLogReportComponent implements OnInit {
  errorLogData: any[] = [];
  pageSize = 10;
  currentPage = 1;
  totalPages = 1;
  isLoading: boolean = false;

  constructor(private errorLogService: ErrorLogReportService) {}

  ngOnInit(): void {
    this.fetchData();
  }

  fetchData(): void {
    this.isLoading = true;
    this.errorLogService.getErrorLogData().subscribe(
      (data: any[]) => {
        this.errorLogData = data;
        this.isLoading = false;

        if (this.errorLogData.length === 0) {
          alert('No data found.');
        } else {
          this.totalPages = Math.ceil(this.errorLogData.length / this.pageSize);
          this.updatePageData();
        }
      },
      (error) => {
        console.error('Error fetching error log data:', error);
        this.isLoading = false;
      }
    );
  }

  updatePageData(): void {
    const startIndex = (this.currentPage - 1) * this.pageSize;
    const endIndex = Math.min(
      startIndex + this.pageSize,
      this.errorLogData.length
    );
    this.currentPage = Math.min(this.currentPage, this.totalPages);
    this.errorLogData = this.errorLogData.slice(startIndex, endIndex);
  }

  goToFirstPage(): void {
    this.currentPage = 1;
    this.fetchData();
  }

  goToPrevPage(): void {
    if (this.currentPage > 1) {
      this.currentPage--;
      this.fetchData();
    }
  }

  goToNextPage(): void {
    if (this.currentPage < this.totalPages) {
      this.currentPage++;
      this.fetchData();
    }
  }

  goToLastPage(): void {
    this.currentPage = this.totalPages;
    this.fetchData();
  }

  get totalPage() {
    let total = 0;
    if (this.errorLogData.length > 0) {
      total = this.getTotalPages();
    }
    return total;
  }

  // Calculate total number of pages based on items per page
  getTotalPages() {
    return Math.ceil(this.errorLogData.length / 10);
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
