import { Component, TemplateRef, ViewChild } from '@angular/core';
import { ManageAgentBranchesService } from '../services/manage-agent-branches.service';
import { Observable } from 'rxjs';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { AgentService } from '../services/agent.service';
import { getCacheData } from '../utils/helper';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { finalize } from 'rxjs/operators';

@Component({
  selector: 'app-manage-agent-branches',
  templateUrl: './manage-agent-branches.component.html',
  styleUrls: ['./manage-agent-branches.component.css'],
})
export class ManageAgentBranchesComponent {
  @ViewChild('manageAgentBranch') manageAgentBranchModal;
  @ViewChild('agentView') manageAgentViewBranchModal;
  bsModalRef: BsModalRef;
  listofModeofPayment = []; // Your array of modes of payment
  selectedModeIds: number[] = []; // Array to hold the selected mode IDs
  type: any = 'add';
  countries: any = [];
  selectedCountry: any = '--Select Country--';
  agents: any = [];
  selectedAgent: any = '--Select Agent--';
  agentBranches: any = [];
  selectedAgentBranch: any = '--Select Branch--';
  branchCode: any = '';
  allAgentBranches: any = [];
  agentBranchDetails: any = null;
  isLoading: boolean = false; // Loader flag

  agentTypeList: any = [];
  agentCountryList: any[];
  agentList: any = [];
  cityList: any = [];
  locationList: any = [];
  modeofPaymentList: any = [];
  branchCurrencyList: any = [];

  listofCurrencies: any = [];
  trAmountLimits: any = [];
  trAmountLimitBank: any = [];
  trAmountLimitDraft: any = [];
  trAmountLimitWalt: any = [];
  listofModeofPayments = []; // Your array of modes of payment


  agentTypeId: any = '';

  manageAgentBranchForm = new FormGroup({
    BranchID: new FormControl(''),
    AgentID: new FormControl('None', Validators.required),
    AgentTypeID: new FormControl('None'),
    AgentBranchName: new FormControl('', Validators.required),
    AgentBranchAddress: new FormControl('', Validators.required),
    AgentBranchPh: new FormControl('', Validators.required),
    AgentBranchFax: new FormControl('', Validators.required),
    AgentBranchEmail: new FormControl(''),
    CountryID: new FormControl('None', Validators.required),
    CityID: new FormControl('None', Validators.required),
    LocationID: new FormControl('None', Validators.required),
    ContactPerson: new FormControl(''),
    IsSubAgent: new FormControl(false),
    IsArebic: new FormControl(false),
    IsActive: new FormControl(false),
    IsHO: new FormControl(false),
    ModeOfPaymentID: new FormControl(''),
    CurrenciesTrAmtLimit: new FormControl(''),
    CurrenciesTrAmtLimit_Bank: new FormControl(''),
    CurrenciesTrAmtLimit_DD: new FormControl(''),
    CurrenciesTrAmtLimit_WALT: new FormControl(''),
    Base_Currency_Id: new FormControl('None', Validators.required),
    AgentType: new FormControl(''),
    Country: new FormControl(''),
    Agent: new FormControl(''),
    City: new FormControl(''),
    Location: new FormControl(''),
    ListofModeOfPaymentforselectedAgent: new FormControl(''),
    ListofCurrencyforBranch: new FormControl(''),
    IndividualTransactionLimitforCASH: new FormControl(''),
    IndividualTransactionLimitforBANK: new FormControl(''),
    IndividualTransactionLimitforDD: new FormControl(''),
    txtRemark: new FormControl(''),
  });

  constructor(
    private agentBranchSvc: ManageAgentBranchesService,
    private agentSvc: AgentService,
    private modalService: BsModalService
  ) {}

  ngOnInit(): void {
    this.getCountries();
    this.getAgentTypeList();
  }

  getCountries() {
    this.agentBranchSvc.getCountryList().subscribe({
      next: (res: any) => {
        this.countries = res;
      },
      error: (err) => {
        this.countries = [];
      },
      complete: () => {},
    });
  }

  onCountryChange(countryId: any) {
    if (countryId) {
      this.getAgentList(countryId);
    }
  }

  getAgentList(countryId) {
    this.agentBranchSvc.getAgentList(countryId).subscribe({
      next: (res: any) => {
        this.agents = res;
      },
      error: (err) => {
        this.agents = [];
      },
      complete: () => {},
    });
  }

  onAgentChange(agentId: any) {
    if (agentId) {
      this.getAgentBranchList(agentId);
    }
  }

  getAgentBranchList(agentId) {
    this.agentBranchSvc.getAgentBranchList(agentId).subscribe({
      next: (res: any) => {
        this.agentBranches = res;
      },
      error: (err) => {
        this.agentBranches = [];
      },
      complete: () => {},
    });
  }

  handleGetAllRecordObservable(observable: Observable<any>): void {
    observable.subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.allAgentBranches = res;
      },
      error: (err) => {
        this.allAgentBranches = [];
      },
      complete: () => {},
    });
  }

  getAllRecord(agentId: any = 0, branchId: any = 0): void {
    // Start the loader
    this.isLoading = true;
   
    this.handleGetAllRecordObservable(
      this.agentBranchSvc.getAllRecord(agentId, branchId)
        .pipe(
          // Use finalize to set isLoading to false after the observable completes
          finalize(() => {
            this.isLoading = false;
          })
        )
    );
  }

  getAllRecordByBranchCode(branchCode: any = 0): void {
    // Start the loader
    this.isLoading = true;
   
    // Handle the observable and stop the loader after it completes
    this.handleGetAllRecordObservable(
      this.agentBranchSvc.getAllRecordByBranchCode(branchCode).pipe(
        finalize(() => {
          // Stop the loader when the observable completes
          this.isLoading = false;
        })
      )
    );
  }

  filterData() {
    if (this.selectedCountry == '--Select Country--') {
      alert('Please Select Country.');
      return;
    }
    if (this.selectedAgent == '--Select Agent--') {
      alert('Please Select Agent.');
      return;
    }
    if (this.selectedAgentBranch == '--Select Branch--') {
      alert('Please Select Branch.');
      return;
    }
    if (
      this.selectedAgent != '--Select Agent--' &&
      this.selectedAgentBranch != '--Select Branch--'
    ) {
      this.getAllRecord(this.selectedAgent, this.selectedAgentBranch);
    }
  }

  filterDataByBranchCode() {
    if (!this.branchCode) {
      alert('Please Enter Branch Code.');
      return;
    }
    if (this.branchCode) {
      this.getAllRecordByBranchCode(this.branchCode);
    }
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  get f() {
    return this.manageAgentBranchForm.value;
  }

  getAgentTypeList() {
    this.agentSvc
      .getAgentTypeList(getCacheData('admin_token'), getCacheData('username'))
      .subscribe({
        next: (res: any) => {
          this.agentTypeList = res;
          if (this.type == 'add') {
            this.getCountryListByAgent(res?.[0]?.Group_Id);
          }
        },
        error: (err) => {
          this.agentTypeList = [];
        },
        complete: () => {},
      });
  }

  onAgentTypeChange(agentId: any) {
    if (agentId != 'None') {
      this.getCountryListByAgent(agentId);
    }
  }

  getCountryListByAgent(
    agentId: any = 0,
    countryId: any = '',
    agent: any = '',
    cityId: any = '',
    locationId: any = ''
  ) {
    this.agentBranchSvc.getCountryListByAgent(agentId).subscribe({
      next: (res: any) => {
        this.agentCountryList = res;
        if (countryId) {
          const country = this.agentCountryList.find(
            (c) => c.CountryId == countryId
          )?.CountryId;
          this.manageAgentBranchForm.patchValue({
            CountryID: country,
          });
          this.getAgentListByCountry(
            this.f.AgentTypeID,
            countryId,
            agent,
            cityId,
            locationId
          );
        }
      },
      error: (err) => {
        this.agentCountryList = [];
      },
      complete: () => {},
    });
  }

  onAgentCountryChange(countryId: any) {
    if (countryId != 'None') {
      this.getAgentListByCountry(this.f.AgentTypeID, countryId);
    }
  }

  getAgentListByCountry(
    agentId: any = 0,
    countryId: any = 0,
    agent: any = '',
    cityId: any = 0,
    locationId: any = 0
  ) {
    this.agentBranchSvc.getAgentListByCountry(agentId, countryId).subscribe({
      next: (res: any) => {
        this.agentList = res;
        if (agent && this.type == 'edit') {
          const agentId = this.agentList.find(
            (a) => a.Agent_ID == agent
          )?.Agent_ID;
          this.manageAgentBranchForm.patchValue({
            AgentID: agentId,
          });
          this.getCity(countryId, cityId, locationId);
          this.getModeofPaymentByAgent(agentId);
          this.getBranchCurrencyByAgent(agentId);
        }
        if (this.type == 'add') {
          this.getModeofPaymentByAgent(this.agentList?.[0]?.Agent_ID);
          this.getBranchCurrencyByAgent(this.agentList?.[0]?.Agent_ID);
        }
      },
      error: (err) => {
        this.agentList = [];
      },
      complete: () => {},
    });
  }

  onAgentListChange(agentId: any) {
    if (agentId != 'None') {
      this.getCity(this.f.CountryID);
      this.getModeofPaymentByAgent(agentId);
      this.getBranchCurrencyByAgent(agentId);
    }
  }

  getCity(countryId: any = 0, cityId: any = 0, locationId: any = 0) {
    this.agentSvc
      .getCity(getCacheData('admin_token'), getCacheData('username'), countryId)
      .subscribe({
        next: (res: any) => {
          this.cityList = res;
          if (this.type == 'edit') {
            const city = this.cityList.find((a) => a.CityID == cityId)?.CityID;
            this.manageAgentBranchForm.patchValue({
              CityID: city,
            });
            this.getLocation(city, this.f.CountryID, locationId);
          }
          if (this.f.CountryID == 'None' && this.type == 'add') {
            this.getLocation(res?.[0]?.CityID, this.f.CountryID);
          }
        },
        error: (err) => {
          this.cityList = [];
        },
        complete: () => {},
      });
  }

  onCityChange(cityId: any) {
    if (cityId != 'None') {
      this.getLocation(cityId, this.f.CountryID);
    }
  }

  getLocation(cityId: any = 0, countryId: any = 0, locationId: any = 0) {
    this.agentSvc
      .getLocation(
        getCacheData('admin_token'),
        getCacheData('username'),
        cityId,
        countryId
      )
      .subscribe({
        next: (res: any) => {
          this.locationList = res;
          if (this.type == 'edit') {
            const location = this.locationList.find(
              (a) => a.LocationID == locationId
            )?.LocationID;
            this.manageAgentBranchForm.patchValue({
              LocationID: location,
            });
          }
        },
        error: (err) => {
          this.locationList = [];
        },
        complete: () => {},
      });
  }

  getModeofPaymentByAgent(agentId: any = 0) {
    this.agentBranchSvc.getModeofPaymentByAgent(agentId).subscribe({
      next: (res: any) => {
        this.modeofPaymentList = res;
      },
      error: (err) => {
        this.modeofPaymentList = [];
      },
      complete: () => {},
    });
  }

  getBranchCurrencyByAgent(agentId: any = 0) {
    this.agentBranchSvc.getBranchCurrencyByAgent(agentId).subscribe({
      next: (res: any) => {
        this.branchCurrencyList = res;
        this.manageAgentBranchForm.patchValue({
          Base_Currency_Id: res?.[0]?.Currency_Id,
        });
      },
      error: (err) => {
        this.branchCurrencyList = [];
      },
      complete: () => {},
    });
  }

  openAgentBranchModal(type: any) {
    if (type == 'add') {
      this.manageAgentBranchForm.reset({
        AgentTypeID: 'None',
        CountryID: 'None',
        AgentID: 'None',
        CityID: 'None',
        LocationID: 'None',
      });

      this.openModal(this.manageAgentBranchModal);
    }else if (type === 'view') {
      this.openModal(this.manageAgentViewBranchModal);
    }else if (type === "edit"){
      this.openModal(this.manageAgentBranchModal);
    }
    this.type = type;
    // this.openModal(this.manageAgentBranchModal);
  }

  openModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template, {
      class: 'modal-lg',
    });
  }

  addModeofPayment() {
    if (this.f.ModeOfPaymentID == 'All') {
      alert('Please Select Mode of Payment');
      return;
    }
  
    // Helper function to check if a mode of payment exists in the list
    const checkExistence = (array, value) =>
      array.some((item) => item.Value === value);
  
    if (this.f.ModeOfPaymentID === '-1') {
      // If ModeOfPaymentID is -1, add all modes of payment from modeofPayments list
      this.modeofPaymentList.forEach(mode => {
        if (!checkExistence(this.listofModeofPayments, mode.ModeOfPayment_Name)) {
          this.addNewItem(
            this.listofModeofPayments,
            'Value',
            mode.ModeOfPayment_Name,
            'Id'
          );
        }
      });
      alert('All modes of payment have been added.');
    } else {
      // Existing logic for adding a single mode of payment
      const isCurrencyDifferentInList = !checkExistence(
        this.listofModeofPayments,
        this.f.ModeOfPaymentID
      );
  
      if (isCurrencyDifferentInList) {
        this.addNewItem(
          this.listofModeofPayments,
          'Value',
          this.f.ModeOfPaymentID,
          'Id'
        );
      } else {
        alert('This mode of payment already exists in the list.');
      }
    }
  }
  
  // This is an example implementation of addNewItem function
  // It should be defined according to your specific requirements.
 

  

  onSelectChange(event: any) {
    // Cast event.target to HTMLSelectElement to access selectedOptions as HTMLOptionElement[]
    const selectedOptions = Array.from((event.target as HTMLSelectElement).selectedOptions) as HTMLOptionElement[];
  
    // Extract and parse the values of the selected options
    this.selectedModeIds = selectedOptions.map(option => parseInt(option.value, 10));
  }
  
  

  removeModeofPayment() {
    if (this.selectedModeIds.length > 0) {
      // Remove the selected items from listofModeofPayments
      this.listofModeofPayments = this.listofModeofPayments.filter(
        mode => !this.selectedModeIds.includes(mode.Id)
      );
  
      // Optionally, reset the selectedModeIds
      this.selectedModeIds = [];
  
      // Update the form value if needed
      this.manageAgentBranchForm.patchValue({
        ModeOfPaymentID: '-1',
      });
  
      // Optionally, provide feedback
      alert('Selected modes of payment have been removed.');
    } else {
      alert('Please select at least one mode of payment to remove.');
    }
  }
  

  addNewItem(list, valueKey, newValue, idKey) {
    if (newValue != null && newValue !== '') {
      // Ensure numericValue is converted from string to a number if necessary
      const numericValue = newValue;
  
      // Check if the value already exists in the list
      const isValueExists = list.some(
        (item) => item[valueKey] === numericValue
      );
  
      // If the value doesn't exist, add a new item
      if (!isValueExists) {
        let newItem = {
          [idKey]: list.length > 0 ? list[list.length - 1][idKey] + 1 : 1,
          [valueKey]: numericValue,
        };
        list.push(newItem);
      }
    }
  }

  addIndividualTransactionLimit() {
    if (this.f.Base_Currency_Id == 'None') {
      alert('Please Select Branch Currency');
      return;
    }
    if (!this.f.CurrenciesTrAmtLimit) {
      alert('Please Fill Cash');
      return;
    }
    if (!this.f.CurrenciesTrAmtLimit_Bank) {
      alert('Please Fill Bank');
      return;
    }

    if (!this.f.CurrenciesTrAmtLimit_DD) {
      alert('Please Fill Draft');
      return;
    }
    if (!this.f.CurrenciesTrAmtLimit_WALT) {
      alert('Please Fill Walt');
      return;
    }

    // const checkExistence = (array, value) =>
    //   array.some((item) => item.Value === value);

    // const isCurrencyDifferentInList = !checkExistence(
    //   this.listofCurrencies,
    //   this.f.Base_Currency_Id
    // );

    const isCurrencyDifferentInList = this.listofCurrencies.find(
      (c) => c.Id == this.f.Base_Currency_Id
    );

    if (isCurrencyDifferentInList) {
      alert('This currency already exists in the list.');
      return;
    }

    if (this.f.Base_Currency_Id != 'None') {
      const currencyName =
        this.branchCurrencyList.find(
          (a) => a.Currency_Id == this.f.Base_Currency_Id
        )?.CurrencyShortName ?? '';
      this.addNewItem(this.listofCurrencies, 'Value', currencyName, 'Id');
    }

    if (this.f.CurrenciesTrAmtLimit?.length) {
      this.addNewItem(
        this.trAmountLimits,
        'Value',
        this.f.CurrenciesTrAmtLimit,
        'Id'
      );
    }
    if (this.f.CurrenciesTrAmtLimit_Bank?.length) {
      this.addNewItem(
        this.trAmountLimitBank,
        'Value',
        this.f.CurrenciesTrAmtLimit_Bank,
        'Id'
      );
    }
    if (this.f.CurrenciesTrAmtLimit_DD?.length) {
      this.addNewItem(
        this.trAmountLimitDraft,
        'Value',
        this.f.CurrenciesTrAmtLimit_DD,
        'Id'
      );
    }
    if (this.f.CurrenciesTrAmtLimit_WALT?.length) {
      this.addNewItem(
        this.trAmountLimitWalt,
        'Value',
        this.f.CurrenciesTrAmtLimit_WALT,
        'Id'
      );
    }

    // if (
    //   isCurrencyDifferentInList ||
    //   !checkExistence(this.trAmountLimits, this.f.CurrenciesTrAmtLimit) ||
    //   !checkExistence(
    //     this.trAmountLimitBank,
    //     this.f.CurrenciesTrAmtLimit_Bank
    //   ) ||
    //   !checkExistence(
    //     this.trAmountLimitDraft,
    //     this.f.CurrenciesTrAmtLimit_DD
    //   ) ||
    //   !checkExistence(this.trAmountLimitWalt, this.f.CurrenciesTrAmtLimit_WALT)
    // ) {
    // } else {
    //   alert('This currency already exists in the list.');
    //   return;
    // }
  }

  removeIndividualTransactionLimit() {
    if (
      this.listofCurrencies?.length &&
      this.trAmountLimits?.length &&
      this.trAmountLimitBank?.length &&
      this.trAmountLimitDraft?.length &&
      this.trAmountLimitWalt?.length
    ) {
      this.listofCurrencies.pop();
      this.trAmountLimits.pop();
      this.trAmountLimitBank.pop();
      this.trAmountLimitDraft.pop();
      this.trAmountLimitWalt.pop();
      this.manageAgentBranchForm.patchValue({
        CurrenciesTrAmtLimit: '',
        CurrenciesTrAmtLimit_Bank: '',
        CurrenciesTrAmtLimit_DD: '',
        CurrenciesTrAmtLimit_WALT: '',
      });
    }
  }

  addAgentBranch() {
    if (!this.manageAgentBranchForm.valid) {
      alert('Please Fill Required Fields!');
      return;
    }
    if (!this.f.CurrenciesTrAmtLimit && this.trAmountLimits.length == 0) {
      alert('Please Fill Required Fields!');
      return;
    }
    if (
      !this.f.CurrenciesTrAmtLimit_Bank &&
      this.trAmountLimitBank.length == 0
    ) {
      alert('Please Fill Required Fields!');
      return;
    }
    if (
      !this.f.CurrenciesTrAmtLimit_DD &&
      this.trAmountLimitDraft.length == 0
    ) {
      alert('Please Fill Required Fields!');
      return;
    }
    if (
      !this.f.CurrenciesTrAmtLimit_WALT &&
      this.trAmountLimitWalt.length == 0
    ) {
      alert('Please Fill Required Fields!');
      return;
    }
    if (!this.f.ModeOfPaymentID && this.listofModeofPayments.length == 0) {
      alert('Please Fill Required Fields!');
      return;
    }
    if (this.f.Base_Currency_Id == 'None') {
      alert('Please Select Currency.');
      return;
    }

    let payload;
    payload = {
      BranchID: this.f.BranchID,
      AgentID: this.f.AgentID,
      AgentBranchName: this.f.AgentBranchName,
      AgentBranchAddress: this.f.AgentBranchAddress,
      AgentBranchPh: this.f.AgentBranchPh,
      AgentBranchFax: this.f.AgentBranchFax,
      AgentBranchEmail: this.f.AgentBranchEmail,
      CountryID: this.f.CountryID,
      CityID: this.f.CityID,
      LocationID: this.f.LocationID,
      ContactPerson: this.f.ContactPerson,
      Currencies: this.listofCurrencies,
      ModeOfPayment: this.listofModeofPayments,
      CurrenciesTrAmtLimit: this.trAmountLimits,
      CurrenciesTrAmtLimit_Bank: this.trAmountLimitBank,
      CurrenciesTrAmtLimit_DD: this.trAmountLimitDraft,
      CurrenciesTrAmtLimit_WALT: this.trAmountLimitWalt,
      EnteredBy: getCacheData('G_UserID'),
      IsHO: this.f.IsHO ? this.f.IsHO : false,
      IsSubAgent: this.f.IsSubAgent ? this.f.IsSubAgent : true,
      IsArebic: this.f.IsArebic ? this.f.IsArebic : true,
      IsActive: this.f.IsActive ? this.f.IsActive : false,
    };

    console.log(payload);

    const serviceMethod =
      this.type === 'add' ? 'addAgentBranch' : 'updateAgentBranch';

    this.agentBranchSvc[serviceMethod](payload).subscribe({
      next: (res: any) => {
        this.modalService.hide();
        const message = this.type === 'edit' ? 'updated' : 'added';
        alert(`Agent Branche information ${message} successfully.`);
        this.getAllRecord(this.selectedAgent, this.selectedAgentBranch);
      },
      error: (err) => {
        this.modalService.hide();
        alert(err?.error?.message || 'Something went wrong');
      },
      complete: () => {
        this.modalService.hide();
      },
    });
  }

  viewAgentBranch(branchId: any) {
    if (branchId) {
      this.getAgentBranchById(branchId, 'view');
    }
  }

  editAgentBranch(branchId: any) {
    if (branchId) {
      this.getAgentBranchById(branchId, 'edit');
    }
  }

  getAgentBranchById(branchId = 0, type = 'view') {
    switch (type) {
      case 'view':
        this.getAgentView(branchId);
        break;
      case 'edit':
        this.getAgentEdit(branchId);
        break;

      default:
        break;
    }
  }

  getAgentEdit(branchId) {
    this.agentBranchSvc.editAgentBranch(branchId).subscribe({
      next: (res: any) => {
        this.getCountryListByAgent(
          res?.[0]?.UserGroup,
          res?.[0]?.CountryID,
          res?.[0]?.AgentID,
          res?.[0]?.CityID,
          res?.[0]?.LocationID
        );

        this.manageAgentBranchForm.patchValue({
          BranchID: res?.[0]?.AgentBranchID,
          AgentTypeID: res?.[0]?.UserGroup,
          IsSubAgent: res?.[0]?.IsSubAgent,
          AgentBranchName: res?.[0]?.AgentBranchName,
          AgentBranchAddress: res?.[0]?.AgentBranchAdd,
          AgentBranchPh: res?.[0]?.AgentBranchPh,
          AgentBranchFax: res?.[0]?.AgentBranchFax,
          AgentBranchEmail: res?.[0]?.AgentBranchEmail,
          ContactPerson: res?.[0]?.ContactPerson,
          IsArebic: res?.[0]?.IsArebic,
          IsActive: res?.[0]?.IsActive,
          IsHO: res?.[0]?.IsHO,
        });
        this.listofModeofPayments = res?.[0]?.ModeOfPayment;
        this.listofCurrencies = res?.[0]?.Currencies;
        this.trAmountLimits = res?.[0]?.CurrenciesTrAmtLimit;
        this.trAmountLimitBank = res?.[0]?.CurrenciesTrAmtLimit_Bank;
        this.trAmountLimitDraft = res?.[0]?.CurrenciesTrAmtLimit_DD;
        this.trAmountLimitWalt = res?.[0]?.CurrenciesTrAmtLimit_WALT;
        this.openAgentBranchModal('edit');
      },
      error: (err) => {
        alert(err?.error?.message || 'Something went wrong');
      },
      complete: () => {},
    });
  }

  getAgentView(branchId) {
    this.agentBranchSvc.viewAgentBranch(branchId).subscribe({
      next: (res: any) => {
        this.manageAgentBranchForm.patchValue({
          BranchID: res?.[0]?.BranchID,
          AgentType: res?.[0]?.AgentType,
          Country: res?.[0]?.Country,
          Agent: res?.[0]?.Agent,
          City: res?.[0]?.City,
          Location: res?.[0]?.Location,
          IsSubAgent: res?.[0]?.IsSubAgent,
          ListofModeOfPaymentforselectedAgent:
            res?.[0]?.ListofModeOfPaymentforselectedAgent,
          IndividualTransactionLimitforCASH:
            res?.[0]?.IndividualTransactionLimitforCASH,
          IndividualTransactionLimitforBANK:
            res?.[0]?.IndividualTransactionLimitforBANK,
          IndividualTransactionLimitforDD:
            res?.[0]?.IndividualTransactionLimitforDD,
          ListofCurrencyforBranch: res?.[0]?.ListofCurrencyforBranch,
          AgentBranchName: res?.[0]?.BranchSubAgent,
          AgentBranchAddress: res?.[0]?.Address,
          AgentBranchPh: res?.[0]?.Phone,
          AgentBranchFax: res?.[0]?.Fax,
          AgentBranchEmail: res?.[0]?.Email,
          ContactPerson: res?.[0]?.ContactPerson,
          IsArebic: res?.[0]?.IsArabic,
        });
        this.agentBranchDetails = res[0];

        this.openAgentBranchModal('view');
      },
      error: (err) => {
        alert(err?.error?.message || 'Something went wrong');
      },
      complete: () => {},
    });
  }

  approveAgentBranch() {
    if (this.f.BranchID) {
      this.agentBranchSvc.approveAgentBranch(this.f.BranchID).subscribe({
        next: (res: any) => {
          this.modalService.hide();
        },
        error: (err) => {
          this.modalService.hide();
          alert(err?.error?.message || 'Something went wrong');
        },
        complete: () => {
          this.modalService.hide();
        },
      });
    }
  }
}
