
import { Component, OnInit,TemplateRef, ViewChild } from '@angular/core';
import { ManageComplianceRejectionService } from '../services/manage-compliance-rejection.service';
import { FormGroup, FormControl, Validators } from '@angular/forms';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { getCacheData } from '../utils/helper';

@Component({
  selector: 'app-manage-compliance-rejection',
  templateUrl: './manage-compliance-rejection.component.html',
  styleUrls: ['./manage-compliance-rejection.component.css']
})
export class ManageComplianceRejectionComponent implements OnInit {
  @ViewChild('RejectionReason') manageLocationModal;
  bsModalRef: BsModalRef;
  
  rejectionReasons: any[] = [];
  rejectionReasonsDrope: any[] = [];
  type: any = 'add';
  rejectionReasonsForm = new FormGroup({
    ID: new FormControl(),
    Reason: new FormControl('All', Validators.required),
    FlagShowTo: new FormControl('None', Validators.required),
    IsActive: new FormControl(false, Validators.required),
  });
  
  constructor(private manageComplianceRejectionService: ManageComplianceRejectionService,private modalService: BsModalService) {}

  ngOnInit(): void {
    this.getRejectionReasons();
    this. getRejectionReasonsDrop()
  }

  getRejectionReasons() {
    this.manageComplianceRejectionService.rejectionReason().subscribe(
      (data: any) => {
        this.rejectionReasons = data;
      },
      (error: any) => {
        console.error('Error fetching rejection reasons:', error);
      }
    );
  }
  getRejectionReasonsDrop() {
    this.manageComplianceRejectionService.getRejectionReason().subscribe(
      (data: any) => {
        this.rejectionReasonsDrope = data;
      },
      (error: any) => {
        console.error('Error fetching rejection reasons:', error);
      }
    );
  }

  openModal(template: TemplateRef<any>) {
    this.bsModalRef = this.modalService.show(template);
  }

  openrejectionReasonsModal(type: any) {
    this.type = type;

    if (type === 'add') {
      this.rejectionReasonsForm.reset({
        Reason: '',
        FlagShowTo: '',
        IsActive: false,
      });
      
    }

    this.openModal(this.manageLocationModal);
  }


  
  get f() {
    return this.rejectionReasonsForm.value;
  }

  addReason() {
    if (!this.rejectionReasonsForm.valid) {
      alert('Please Fill Required Fields!');
      return;
    }

    if (this.f.Reason == '') {
      alert('Please Enter Reason!');
      return;
    }

    if (this.f.FlagShowTo == '') {
      alert('Please Enter FlagShowTo!');
      return;
    }

   

    let payload;
    payload = {
      ID: 0,
      Reason: this.f.Reason,
      FlagShowTo: this.f.FlagShowTo,
      IsActive: this.f.IsActive,
      UserID: getCacheData('G_UserID')
     
    };

    if (this.type === 'edit') {
      payload = {
        ...payload,
        ID: this.f.ID,
      };
    }

    const serviceMethod =
      this.type === 'add' ? 'rejectionReasonAdd' : 'updateReason';

    this.manageComplianceRejectionService[serviceMethod](
   
      payload
    ).subscribe({
      next: (res: any) => {
        this.modalService.hide();
   
        this.getRejectionReasons();
        console.log(res);
        // const message = this.type === 'edit' ? 'updated' : 'added';
        alert(res);
      },
      error: (err) => {
        this.modalService.hide();
        alert(err?.error?.message || 'Something went wrong');
      },
      complete: () => {
        this.modalService.hide();
      },
    });
  }
 

  async editReason(type:any,ReasonID: any) {
    const res = await this.manageComplianceRejectionService.rejectionReasonEdit(ReasonID).toPromise();
    const matchedOption = this.rejectionReasonsDrope.find(option => option.ID == res[0].Flag);

console.log(matchedOption)

    this.rejectionReasonsForm.patchValue({
      ID: res[0].ID,
      Reason: res[0].RejectionReason,
      FlagShowTo: matchedOption ? matchedOption.ID : null,
      IsActive: res[0].IsActive

    });

    this.openrejectionReasonsModal(type);
  }


  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
}
