import { Component, ElementRef, TemplateRef, ViewChild } from '@angular/core';
import * as XLSX from 'xlsx';
import { SearchTransactionsService } from '../services/search-transactions.service';
import { SearchTransactionModeWiseService } from '../services/search-transaction-mode-wise.service';
import { AuthService } from '../services/auth.service';
import { BsModalRef, BsModalService } from 'ngx-bootstrap/modal';
import { ViewTransactionStatusForAgentService } from '../view-transaction-status-for-agent.service';

@Component({
  selector: 'app-search-transaction-mode-wise',
  templateUrl: './search-transaction-mode-wise.component.html',
  styleUrls: ['./search-transaction-mode-wise.component.css'],
})
export class SearchTransactionModeWiseComponent {
  @ViewChild('transactionTable') transactionTable: ElementRef;
  @ViewChild('viewTransactionReceipt') viewTransactionReceiptModal;
  bsTransactionReceiptModalRef: BsModalRef;

  lcCurrencyList: any = [];
  selectedLcCurrency: any;
  sendAgentList: any = [];
  selectedSendAgent: any;
  fcCurrencyList: any = [];
  selectedFcCurrency: any;
  receiveAgentList: any = [];
  selectedReceiveAgent: any;
  customerFullName: any = '';
  beneficiaryFullName: any = '';
  fromAmount: any = '';
  toAmount: any = '';
  isUsd: any = false;
  startDate: any = '';
  endDate: any = '';
  allTransactionDetails: any = [];
  modes: any = [
    {
      id: 1,
      type: 'Bank',
    },
    {
      id: 2,
      type: 'Cash',
    },
  ];
  selectedMode: any = 1;
  pageSize: number = 20; // Number of results per page
  currentPage: number = 1;
  isLoading: boolean = false;
  hasMoreResults: boolean = true;
  receiptData: any = {};

  constructor(
    private searchTransactionSvc: SearchTransactionsService,
    private searchTransactionModeWiseSvc: SearchTransactionModeWiseService,
    private ViewTransactionStatusForAgentSvc: ViewTransactionStatusForAgentService,
    private modalService: BsModalService,
    private authSvc: AuthService
  ) {}

  ngOnInit(): void {
    this.getLcCurrencyList();
    this.getFcCurrencyList();
    this.getReceivingAgentList(-1);
    this.startDate = this.authSvc.getTodayDate();
    this.endDate = this.authSvc.getTodayDate();
  }

  getLcCurrencyList() {
    this.searchTransactionSvc.getLcCurrencyList().subscribe({
      next: (res: any) => {
        this.lcCurrencyList = res;
        this.selectedLcCurrency = res?.[0]?.Currency_Id;
        this.getSendAgentList(this.selectedLcCurrency);
      },
      error: (err) => {
        this.lcCurrencyList = [];
      },
      complete: () => {},
    });
  }

  onLcCurrencyChange(currencyId: any) {
    if (currencyId != -1) {
      this.getSendAgentList(currencyId);
    }
  }

  getSendAgentList(currencyId: any = 0) {
    this.searchTransactionSvc.getSendAgentList(currencyId).subscribe({
      next: (res: any) => {
        this.sendAgentList = res;
        if (currencyId > 0) {
          this.selectedSendAgent = res?.[0]?.agentid;
        }
      },
      error: (err) => {
        this.sendAgentList = [];
      },
      complete: () => {},
    });
  }

  getFcCurrencyList() {
    this.searchTransactionSvc.getFcCurrencyList().subscribe({
      next: (res: any) => {
        this.fcCurrencyList = res;
        this.selectedFcCurrency = res?.[0]?.Currency_Id;
      },
      error: (err) => {
        this.fcCurrencyList = [];
      },
      complete: () => {},
    });
  }

  onFcCurrencyChange(currencyId: any) {
    if (currencyId != -1) {
      this.getReceivingAgentList(currencyId);
    }
  }

  getReceivingAgentList(currencyId: any = -1) {
    this.searchTransactionSvc.getReceivingAgentList(currencyId).subscribe({
      next: (res: any) => {
        this.receiveAgentList = res;
        if (currencyId == -1) {
          this.selectedReceiveAgent = res?.[0]?.agentid;
        }
      },
      error: (err) => {
        this.receiveAgentList = [];
      },
      complete: () => {},
    });
  }

  searchTransaction() {
    if (!this.startDate && !this.endDate) {
      alert('Please Select Start & End Date!');
      return;
    }

    this.allTransactionDetails = [];
    this.currentPage = 1;
    this.hasMoreResults = true;
    this.loadTransactions();
  }

  loadTransactions() {
    if (this.isLoading || !this.hasMoreResults) {
      return;
    }

    this.isLoading = true;

    let payload: any = {
      ModeType: this.selectedMode,
      LcCurrencyID: this.selectedLcCurrency,
      SendAgentID: this.selectedSendAgent ? this.selectedSendAgent : -1,
      FcCurrencyID: this.selectedFcCurrency,
      ReceiveAgentID: this.selectedReceiveAgent
        ? this.selectedReceiveAgent
        : -1,
      CustFullname: this.customerFullName ? this.customerFullName : '',
      Benfullname: this.beneficiaryFullName ? this.beneficiaryFullName : '',
      Fromamount: this.fromAmount ? this.fromAmount : '',
      ToAmount: this.toAmount ? this.toAmount : '',
      IsAmtInUSD: this.isUsd ? '1' : '0',
      StartDate: this.startDate,
      EndDate: this.endDate,
      Page: this.currentPage,
      PageSize: this.pageSize,
    };

    this.searchTransactionModeWiseSvc
      .searchTransactionDetail(payload)
      .subscribe({
        next: (res: any) => {
          if (res?.length == 0) {
            this.hasMoreResults = false;
            return;
          }
          this.allTransactionDetails.push(...res);
          this.currentPage++;
        },
        error: () => {
          this.allTransactionDetails = [];
          this.isLoading = false;
        },
        complete: () => {
          this.isLoading = false;
        },
      });
  }

  exportToExcel() {
    const ws: XLSX.WorkSheet = XLSX.utils.table_to_sheet(
      this.transactionTable.nativeElement
    );
    const wb: XLSX.WorkBook = XLSX.utils.book_new();
    XLSX.utils.book_append_sheet(wb, ws, 'Sheet1');
    const fileName = `Search_Transaction_Mode_Wise${Date.now()}.xlsx`;
    XLSX.writeFile(wb, fileName);
  }

  getTotal(property: string): number {
    const sanitizedProperty = property.replace(/\s+/g, '');

    if (this.allTransactionDetails?.[0]?.hasOwnProperty(sanitizedProperty)) {
      return this.allTransactionDetails[0][sanitizedProperty];
    }

    return 0;
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  onScroll(event: any) {
    const { scrollTop, scrollHeight, clientHeight } = event.target;
    if (scrollTop + clientHeight >= scrollHeight - 10) {
      this.loadTransactions();
    }
  }

  getTransactionNumberDetail(item) {
    const trnNo = item?.TransactionNumber;
    this.ViewTransactionStatusForAgentSvc.getTransactionReport(trnNo).subscribe(
      (res: any) => {
        if (res?.[0]?.IsDuplicate == true) {
          alert('No data found.');
          return;
        }
        this.receiptData = res?.[0];
        this.openTransactionReceiptModal(this.viewTransactionReceiptModal);
      }
    );
  }

  openTransactionReceiptModal(template: TemplateRef<any>) {
    this.bsTransactionReceiptModalRef = this.modalService.show(template, {
      class: 'modal-lg',
    });
  }
}
