import { Component, OnInit } from '@angular/core';
import { SendReceiveTransactionListService } from '../services/send-receive-transaction-list.service';

@Component({
  selector: 'app-send-receive-transaction-list',
  templateUrl: './send-receive-transaction-list.component.html',
  styleUrls: ['./send-receive-transaction-list.component.css'],
})
export class SendReceiveTransactionListComponent implements OnInit {
  reports: string[] = [];
  selectedReport: string = '';
  countries: { id: number, name: string }[] = []; // To store country data
  selectedCountry: string = '';
  startDate: string = '';
  endDate: string = '';

  constructor(private transactionService: SendReceiveTransactionListService) {}

  ngOnInit() {
    this.getReports();
    this.getCountries(); // Fetch countries on init
    const currentDate = new Date().toISOString().split('T')[0];
    this.startDate = currentDate;
    this.endDate = currentDate;
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  getReports() {
    this.transactionService.getSendReceiveTransactionReport().subscribe(
      (data: any[]) => {
        this.reports = data.map((item) => item.Reports);
      },
      (error) => {
        console.error('Error fetching reports:', error);
      }
    );
  }

  getCountries() {
    this.transactionService.getCountryList().subscribe(
      (data: any[]) => {
        this.countries = data.map((item) => ({
          id: item.CountryID,
          name: item.CountryName,
        }));
      },
      (error) => {
        console.error('Error fetching countries:', error);
      }
    );
  }

  onReportSelect() {
    console.log('Selected Report:', this.selectedReport);
  }

  onCountrySelect() {
    console.log('Selected Country:', this.selectedCountry);
  }
}
