import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root',
})
export class CountryWiseCommissionService {
  url = environment.apiUrl;

  constructor(private http: HttpClient) {}

  getSendingCountry(token: any, username) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country-wise-commission/sending-country`,
      {
        headers: headers,
      }
    );
  }

  getReceivingCountry(
    token: any,
    username,
    countryID: any = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country-wise-commission/receive-country?CountryID=${countryID}
     `,
      {
        headers: headers,
      }
    );
  }

  getModeofPayment(
    token: any,
    username,
    payOutCountryId: any = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country-wise-commission/mode-of-payment?PayOutCountryID=${payOutCountryId}
     `,
      {
        headers: headers,
      }
    );
  }

  getAllCountryWiseCommission(
    token: any,
    username,
    payInCountryId: any = 0,
    payOutCountryId: any = 0,
    modeofPaymentId: any = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/agent-wise-rate/country-wise-commission?PayInCountryID=${payInCountryId}&PayOutCountryID=${payOutCountryId}&ModeOfPayment_ID=${modeofPaymentId}
     `,
      {
        headers: headers,
      }
    );
  }

  getInsertSendCountry(token: any, username) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country-wise-commission/sendcountry-insert`,
      {
        headers: headers,
      }
    );
  }

  getInsertSendCurrency(token: any, username, payInCountryId = 0) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country-wise-commission/sendcurrency-insert?PayInCountryID=${payInCountryId}`,
      {
        headers: headers,
      }
    );
  }

  getInsertReceiveCountry(token: any, username) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country-wise-commission/receivecountry-insert`,
      {
        headers: headers,
      }
    );
  }

  getTotalCommissionType(token: any, username) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country-wise-commissionn/totalcommission-type-insert`,
      {
        headers: headers,
      }
    );
  }

  getCurrencyType(token: any, username) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country-wise-commission/sendcurrencytype-insert
      `,
      {
        headers: headers,
      }
    );
  }

  addCountryWiseCommission(token: any, username, payload: any) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.post(
      `${environment.apiUrl}/api/master/country-wise-commission/add
      `,
      payload,
      {
        headers: headers,
      }
    );
  }

  updateCountryWiseCommission(token: any, username, payload: any) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.patch(
      `${environment.apiUrl}/api/master/country-wise-commission/update
      `,
      payload,
      {
        headers: headers,
      }
    );
  }

  deleteCountryWiseCommission(token: any, username, payload: any) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.post(
      `${environment.apiUrl}/api/master/country-wise-commission/delete
      `,
      payload,
      {
        headers: headers,
      }
    );
  }

  updateCountryWiseGrid(token: any, username, payload: any) {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.post(
      `${environment.apiUrl}/api/master/country-wise-commission/grid-update
      `,
      payload,
      {
        headers: headers,
      }
    );
  }

  EditCountryWise(id:any) {
    return this.http.get(
      `${environment.apiUrl}/api/master/Country-Wise-Commission/Edit?ID=${id}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }


}
