import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root',
})
export class ManageCountryPermissionService {
  url = environment.apiUrl;

  constructor(private http: HttpClient) {}

  getCountryPermission(token: any, username): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country/country-permission/add/country-permission-dropdown`,
      {
        headers: headers,
      }
    );
  }

  getBaseCountry(token: any, username: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country/country-permission/base-country-dropdown`,
      {
        headers: headers,
      }
    );
  }

  getTargetCountry(token: any, username: any, countryId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country/country-permission/target-country-dropdown?countryId=${countryId}`,
      { headers: headers }
    );
  }

  getAllCountryPermission(
    token: any,
    username,
    baseCountryId = 0,
    targetCountryId = 0,
    active = 1
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country/country-permission?BaseCountryID=${baseCountryId}&TargetCountryID=${targetCountryId}&Active=${active}`,
      {
        headers: headers,
      }
    );
  }

  getSendingCountryPermission(token: any, username: any): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/country/country-permission/add/sending-country-dropDown`,
      {
        headers: headers,
      }
    );
  }

  getReceivingCountryPermission(): Observable<any> {
    return this.http.get(
      `${environment.apiUrl}/api/master/country/country-permission/add/receiving-country-dropDown`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  addCountryPermission(
    token: any,
    username: any,
    payload: any
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.post(
      `${environment.apiUrl}/api/master/country/country-permission`,
      payload,
      {
        headers: headers,
      }
    );
  }

  updateCountryPermission(
    token: any,
    username: any,
    payload: any
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.patch(
      `${environment.apiUrl}/api/master/country/country-permission`,
      payload,
      {
        headers: headers,
      }
    );
  }

  getCountryPermissionList(permissionId: any = 0, baseCountryId: any = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/master/country/country-permission/add/get-data?PermissionID=${permissionId}&BaseCountryID=${baseCountryId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }
}
