import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { getCacheData } from '../utils/helper';

@Injectable({
  providedIn: 'root',
})
export class MapTrMasterService {
  url = environment.apiUrl;

  constructor(private http: HttpClient) {}

  getPayoutXmlList() {
    return this.http.get(
      `${environment.apiUrl}/api/master/map-tr-master/payout-xml-tag-list`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getCountryList() {
    return this.http.get(
      `${environment.apiUrl}/api/master/map-tr-master/country-list`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getCurrencyList(countryId: string) {
    return this.http.get(
      `${environment.apiUrl}/api/master/map-tr-master/currency-list?CountryID=${countryId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getDeliveryOptionList(countryId: string, currencyId: string) {
    return this.http.get(
      `${environment.apiUrl}/api/master/map-tr-master/delivery-option-list?CountryID=${countryId}&PayoutCurrencyID=${currencyId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getReceivingAgentList(
    countryId: string,
    currencyId: string,
    deliveryOption: string
  ) {
    return this.http.get(
      `${environment.apiUrl}/api/master/map-tr-master/receiving-agent-list?CountryID=${countryId}&PayoutCurrencyID=${currencyId}&DeliveryOption=${deliveryOption}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getAllRecord(xmlTypeId: number = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/master/map-tr-master/all-record?PayoutXMLTypeID=${xmlTypeId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getTrTagList(payOutXmlTag: number = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/master/map-tr-master/trtag-list?PayoutXMLTag=${payOutXmlTag}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  updateTrMaster(
    payoutXMLType: number = 0,
    id: number = 0,
    trValueId: number = 0,
    isActive: boolean = false
  ) {
    return this.http.patch(
      `${environment.apiUrl}/api/master/map-tr-master/update?PayoutXMLType=${payoutXMLType}&UserID=1&Id=${id}&TRValueID=${trValueId}&IsActive=${isActive}`,
      {},
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }
}
