import { HttpClient, HttpHeaders } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { Observable } from 'rxjs';
import { environment } from 'src/environments/environment';

@Injectable({
  providedIn: 'root',
})
export class MarginsSpecificSendingReceivingCountryService {
  url = environment.apiUrl;

  constructor(private http: HttpClient) {}

  getAllSendingReceivingCountries(
    token: any,
    username,
    payInCountryId = 0,
    payOutCountryId = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/exchange-margin/agency-margin/sending-and-receiving-country?_PayInCountry=${payInCountryId}&_PayOutCountry=${payOutCountryId}`,
      {
        headers: headers,
      }
    );
  }

  getMarginSendingReceivingCountry(token: any, username): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/exchange-margin/agency-margin/sending-and-receiving-country/sending-country`,
      {
        headers: headers,
      }
    );
  }

  getMarginReceivingCountry(
    token: any,
    username,
    countryId = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/exchange-margin/agency-margin/sending-and-receiving-country/receiving-country?countryID=${countryId}`,
      {
        headers: headers,
      }
    );
  }

  getMarginSendCurrency(token: any, username, countryId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/exchange-margin/agency-margin/sending-and-receiving-country/sending-currency?countryID=${countryId}`,
      {
        headers: headers,
      }
    );
  }

  getMarginReceiveCurrency(
    token: any,
    username,
    countryId = 0
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/exchange-margin/agency-margin/sending-and-receiving-country/receiving-currency?countryID=${countryId}`,
      {
        headers: headers,
      }
    );
  }

  getMarginModeofPayment(token: any, username, countryId = 0): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.get(
      `${environment.apiUrl}/api/master/exchange-margin/agency-margin/sending-and-receiving-country/mode-of-payment?countryID=${countryId}`,
      {
        headers: headers,
      }
    );
  }

  addSpecificSendingReceivingCountry(
    token: any,
    username,
    payload
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.post(
      `${environment.apiUrl}/api/master/exchange-margin/agency-margin/sending-and-receiving-country
      `,
      payload,
      {
        headers: headers,
      }
    );
  }

  updateSpecificSendingReceivingCountry(
    token: any,
    username,
    payload
  ): Observable<any> {
    const headers = new HttpHeaders({
      Authorization: token,
      Accept: 'application/json',
      username: username,
    });
    return this.http.patch(
      `${environment.apiUrl}/api/master/exchange-margin/agency-margin/sending-and-receiving-country
      `,
      payload,
      {
        headers: headers,
      }
    );
  }
}
