import { Component } from '@angular/core';
import { TagMappingService } from '../services/tag-mapping.service';

@Component({
  selector: 'app-tag-mapping',
  templateUrl: './tag-mapping.component.html',
  styleUrls: ['./tag-mapping.component.css'],
})
export class TagMappingComponent {
  mappingMethodList: any = [];
  selectedMappingMethod: any = '0';
  agentList: any = [];
  selectedAgent: any = '0';
  categoryList: any = [];
  selectedCategory: any = '0';
  selectedRequirement: string = '0'; // Default value
  allRecords: any = [];  // This will hold the fetched data
  // xmlTagList: string[] = ['amount', 'consumerId', 'deliveryOption', 'destinationCountry'];
  trTagList: string[] = []; // Initially set to an empty array
  selectTRtag:any
  isLoading: boolean = false;

  constructor(private tagMappingSvc: TagMappingService) {}

  ngOnInit(): void {
    this.getMappingMethodList();
    this.getAgentList();
    this.getCategoryList();
    this.getTritemList(); // New method call

  }

  getMappingMethodList() {
    this.tagMappingSvc.getMappingMethodList().subscribe({
      next: (res: any) => {
        this.mappingMethodList = res;
      },
      error: (err) => {
        this.mappingMethodList = [];
      },
      complete: () => {},
    });
  }

  getAgentList() {
    this.tagMappingSvc.getAgentList().subscribe({
      next: (res: any) => {
        this.agentList = res;
      },
      error: (err) => {
        this.agentList = [];
      },
      complete: () => {},
    });
  }
  getCategoryList() {
    this.tagMappingSvc.getCategoryList().subscribe({
      next: (res: any) => {
        this.categoryList = res;
      },
      error: (err) => {
        this.categoryList = [];
      }
    });
  }
  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }
  checkAndFetchRecords() {

    console.log(this.selectedMappingMethod,this.selectedAgent, this.selectedCategory )
    if (this.selectedMappingMethod !== '0' && this.selectedAgent !== '0' &&
        this.selectedCategory !== '0' && this.selectedRequirement !== '-1') {
      this.fetchRecords();
    }
  }
  
  fetchRecords(): void {
    this.isLoading = true;

    if (this.selectedMappingMethod !== '0' && this.selectedAgent !== '0' && this.selectedCategory !== '0' && this.selectedRequirement !== '-1') {
      this.tagMappingSvc.getAllRecords(
        this.selectedMappingMethod,
        this.selectedAgent,
        this.selectedCategory,
        parseInt(this.selectedRequirement)
      ).subscribe({
        next: (res: any) => {
          this.isLoading = false; 
          this.allRecords = res;
        },
        error: (err) => {
          console.error('Error fetching records:', err);
          this.isLoading = false; 

          this.allRecords = [];

        }
      });
    } else {
      alert('Please select all fields to fetch data.');
    }
  }

  updateTRItemValueField(record: any): void {
    console.log(record)
    this.selectTRtag= record.TRTagName;
    console.log( this.selectTRtag)
  }

  editRecord(record: any) {
    record.editing = true;
  }
  mapRecord(record: any) {
    // Assume necessary data is either part of the record or globally accessible
    this.tagMappingSvc.updateTag( this.selectedMappingMethod, record.XmlId,this.selectedAgent, this.selectTRtag).subscribe({
      next: (res: any) => {
       console.log(res)
       record.editing = false;
      },
      error: (err) => {
        this.categoryList = [];
      }
    });
  }
  // mapRecord(record: any) {
  //   // Assume necessary data is either part of the record or globally accessible
  //   if (record) {
  //     this.tagMappingSvc.updateTag(
  //       this.selectedMappingMethod, 
  //       83, 
  //       this.selectedAgent, 
  //       1001000,  // Assuming UserID is static for example; replace with dynamic data if available
  //       24,
  //     ).subscribe({
  //       next: (res) => {
  //         console.log('Tag updated successfully:', res);
  //         // Additional success handling here
  //       },
  //       error: (err) => {
  //         console.error('Error updating tag:', err);
  //         record.editing = false; // Set editing to false whether success or failure
  //       },
  //       complete: () => {
  //         record.editing = false; // Set editing to false whether success or failure
  //       }
  //     });
  //   } else {
  //     console.error('Missing data for update operation');
  //     record.editing = false;  // Ensure UI consistency even on failure
  //   }
  // }
  

  cancelEdit(record: any) {
    record.editing = false;
  }

  getTritemList() {
    this.tagMappingSvc.getTritemList(this.selectedMappingMethod).subscribe({
      next: (res: any[]) => {
        this.trTagList = res.map(item => item.TRItemTextField); // Map the response to get TRItemTextField values
      },
      error: (err) => {
        console.error('Error fetching tr item list:', err);
        this.trTagList = []; // Reset on error
      }
    });
  }
}