import { Component } from '@angular/core';
import { UploadTransactionsFileService } from '../upload-transactions-file.service';

@Component({
  selector: 'app-upload-transactions-file',
  templateUrl: './upload-transactions-file.component.html',
  styleUrls: ['./upload-transactions-file.component.css'],
})
export class UploadTransactionsFileComponent {
  constructor(
    private uploadTransactionFileSvc: UploadTransactionsFileService
  ) {}

  searchByType: any = '1';
  searchText: any;
  UserName: any;
  Data: any[] = [];
  isLoading: boolean = false;
  currentPage = 1; // Current page number
  itemsPerPage = 15; // Number of items per page

  ngOnInit() {
    this.getUploadTransactionFile();
  }

  getUploadTransactionFile() {
    this.isLoading = true;

    this.uploadTransactionFileSvc.getUploadTransactionFile(0, -1).subscribe({
      next: (res: any) => {
        if (res?.length == 0) {
          alert('No data found.');
          return;
        }
        this.Data = res.map((item) => ({ ...item, expanded: false }));
      },
      complete: () => {
        this.isLoading = false;
      },
    });
  }

  toggleExpansion(item) {
    item.expanded = !item.expanded;
  }

  toggleSideBar() {
    const bodyElement = document.body;
    bodyElement.classList.toggle('sidebar-collapsein');
  }

  SearchType(event) {
    this.searchByType = Number(event.target.value);
  }

  showAuditData() {
    if (this.searchText && this.searchByType) {
      this.uploadTransactionFileSvc
        .getUploadTransactionFile(this.searchText, this.searchByType)
        .subscribe({
          next: (res: any) => {
            if (res?.length == 0) {
              alert('No data found.');
              return;
            }
            this.Data = res.map((item) => ({ ...item, expanded: false }));
          },
          error: (err) => {
            this.Data = [];
          },
          complete: () => {},
        });
    } else {
      this.getUploadTransactionFile();
    }
  }

  firstPage() {
    this.currentPage = 1;
  }

  prevPage() {
    if (this.currentPage > 1) {
      this.currentPage--;
    }
  }

  nextPage() {
    const totalPages = this.getTotalPages();
    if (this.currentPage < totalPages) {
      this.currentPage++;
    }
  }

  lastPage() {
    const totalPages = this.getTotalPages();
    this.currentPage = totalPages;
  }

  get totalPage() {
    let total = 0;
    if (this.Data.length > 0) {
      total = this.getTotalPages();
    }
    return total;
  }

  // Calculate total number of pages based on items per page
  getTotalPages() {
    return Math.ceil(this.Data.length / this.itemsPerPage);
  }

  // Calculate start index for current page
  getStartIndex() {
    return (this.currentPage - 1) * this.itemsPerPage;
  }

  // Calculate end index for current page
  getEndIndex() {
    return this.getStartIndex() + this.itemsPerPage;
  }

  // Get data for the current page
  getDataForCurrentPage(): any[] {
    return this.Data.slice(this.getStartIndex(), this.getEndIndex());
  }

  refresh() {
    this.getUploadTransactionFile();
  }
}
