import { HttpClient } from '@angular/common/http';
import { Injectable } from '@angular/core';
import { environment } from 'src/environments/environment';
import { getCacheData } from './utils/helper';

@Injectable({
  providedIn: 'root',
})
export class VostroAccountBalanceService {
  constructor(private http: HttpClient) {}

  getVostroBalance() {
    return this.http.get(
      `${environment.apiUrl}/api/transaction/vostro-balance/all-record`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getCountry() {
    return this.http.get(
      `${environment.apiUrl}/api/transaction/vostro-balance/country`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getAgent(countryId = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/transaction/vostro-balance/agent?CountryID=${countryId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getCurrency(countryId = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/transaction/vostro-balance/currency?CountryID=${countryId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  getAccInfo(countryId = 0, agentId = 0, currencyId = 0) {
    return this.http.get(
      `${environment.apiUrl}/api/transaction/vostro-balance/acc-info?CountryID=${countryId}&AgentID=${agentId}&CurrencyID=${currencyId}`,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }

  updateVostroBalance(payload: any) {
    return this.http.post(
      `${environment.apiUrl}/api/transaction/vostro-balance/submit`,
      payload,
      {
        headers: {
          Authorization: getCacheData('admin_token'),
          Accept: 'application/json',
          username: getCacheData('username'),
        },
      }
    );
  }
}
